@@ -51,6 +51,7 @@ public class ChronoJump
 	string splashMessage = "";
 	bool creatingDB = false; //on creation and on update always refresh labels
 	bool updatingDB = false;
+	private static string baseDirectory;
 
 
 	public static void Main(string [] args) 
@@ -69,6 +70,10 @@ public class ChronoJump
 		sw.AutoFlush = true;
 */
 
+		baseDirectory = System.IO.Path.Combine(System.AppDomain.CurrentDomain.BaseDirectory,"../../");
+		if(Util.IsWindows())
+			Environment.SetEnvironmentVariable("GST_PLUGIN_PATH",RelativeToPrefix("lib\\gstreamer-0.10"));
+
 		//this call has to be done to chronojump.prg
 		//chronojump.prg createBlankDB
 		//this creates a blank database and exists.
@@ -87,10 +92,15 @@ public class ChronoJump
 					
 			
 		new ChronoJump(args);
+		
 	}
 
 	bool createdSplashWin = false;
 
+	public static string RelativeToPrefix(string relativePath) {
+		return System.IO.Path.Combine(baseDirectory, relativePath);
+	}
+
 	public ChronoJump (string [] args) 
 	{
 		
@@ -103,6 +113,8 @@ public class ChronoJump
 		fakeSplashButton = new Gtk.Button();
 		fakeSplashButton.Clicked += new EventHandler(on_splash_ended);
 
+		LongoMatch.Video.Capturer.GstCameraCapturer.InitBackend("");
+
 		thread = new Thread(new ThreadStart(sqliteThings));
 		GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
 		thread.Start(); 
@@ -137,6 +149,9 @@ public class ChronoJump
 
 		Log.WriteLine(string.Format("Chronojump version: {0}", progVersion));
 
+		//to store user videos and photos
+		Util.CreateMultimediaDirsIfNeeded();
+		
 		//move database to new location if chronojump version is before 0.7
 		moveDatabaseToNewLocationIfNeeded();
 
@@ -247,6 +262,7 @@ Log.WriteLine("doing backup");
 			}
 
 			Log.WriteLine ( Catalog.GetString ("tables already created") ); 
+		
 
 			//check for bad Rjs (activate if program crashes and you use it in the same db before v.0.41)
 			//SqliteJump.FindBadRjs();
@@ -313,8 +329,10 @@ Log.WriteLine("doing backup");
 			if( versionAvailableKnown.Length > 0 && new Version(versionAvailableKnown) > new Version(progVersion) ) 
 				messageToShowOnBoot += "\n" + Catalog.GetString("Chronojump crashed before.") + "\n" +
 				       Catalog.GetString("Please, update to new version: ") + versionAvailableKnown + "\n";
-			else
+			else {
 				messageToShowOnBoot += messageChrashedBefore;
+				SqlitePreferences.Update("videoOn", "False", false);
+			}
 		}
 		
 		
@@ -496,7 +514,7 @@ Console.WriteLine("--6--");
 			
 
 		Thread.Sleep (50);
-		Log.Write(" (PulseGTK:" + thread.ThreadState.ToString() + ") ");
+		//Log.Write(" (PulseGTK:" + thread.ThreadState.ToString() + ") ");
 		return true;
 	}
 	
@@ -568,6 +586,10 @@ Console.WriteLine("--6--");
 			"\n\n" +	
 			Catalog.GetString("Your help is needed.") + "\n";
 
+	
+		messageChrashedBefore += "\n" + Catalog.GetString("Experimental webcam record has been disabled.") + "\n";
+
+
 		/*
 		 * This are the only outputs to Console. Other's use Log that prints to console and to log file
 		 * this doesn't go to log because it talks about log
