@@ -20,6 +20,8 @@
 
 using System;
 using Mono.Unix;
+//do not use gtk or gdk because this class is used by the server
+//see UtilGtk for eg color definitions
 
 public class Constants
 {
@@ -38,7 +40,9 @@ public class Constants
 		"Carlos J. Gil Bellosta (http://www.datanalytics.com)\n" + Catalog.GetString("Statistics support.") 
 	};
 	public static string [] Documenters = {
-		"Xavier de Blas Foix (xaviblas@gmail.com)\n" 
+		"Xavier de Blas Foix (xaviblas@gmail.com)\n\n",
+		"Helena Olsson (hjolsson@gmail.com)\n",
+		"(" + Catalog.GetString("Chronojump Manual English translation") + ")"
 	};
 	
 	public static string ChronojumpWebsite = "http://www.chronojump.org";
@@ -52,8 +56,9 @@ public class Constants
 	public const string FvIndexFormula = "F/V sj+(100%)/sj *100";
 	public const string IeIndexFormula = "IE (cmj-sj)/sj *100";
 	public const string IubIndexFormula = "IUB (abk-cmj)/cmj *100";
+	public const string SubtractionBetweenTests = "Subtraction between tests";
 
-	//tests types
+	//tests types (dont' use character '-' will be used multimedia file names)
 	public enum TestTypes { JUMP, JUMP_RJ, RUN, RUN_I, RT, PULSE, MULTICHRONOPIC }
 	public static string JumpSimpleName = "Jump simple";
 	public static string JumpReactiveName = "Jump reactive";
@@ -167,26 +172,33 @@ public class Constants
 		"(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")*9.81*" +
 		"SQRT(2*9,81* " + Catalog.GetString("height") + "(m))";
 */
-	public static string PotencyLewisFormula = Catalog.GetString("Peak power")+ " (Lewis, 1974) \n" +
+	public static string PotencyLewisFormulaShort = Catalog.GetString("Peak power") + " (Lewis, 1974)";
+	public static string PotencyLewisFormula = PotencyLewisFormulaShort + "\n" +
 		"(SQRT(4,9)*9,8*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ") * SQRT(" + Catalog.GetString("height") + "(m)))";
 	
-	public static string PotencyHarmanFormula = Catalog.GetString("Peak power") + " (Harman, 1991) \n" +
+	
+	public static string PotencyHarmanFormulaShort = Catalog.GetString("Peak power") + " (Harman, 1991)";
+	public static string PotencyHarmanFormula = PotencyHarmanFormulaShort + "\n" +
 		"(61.9*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (36*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -1822";
 	
-	public static string PotencySayersSJFormula = Catalog.GetString("Peak power") + " SJ (Sayers, 1999) \n" +
+	public static string PotencySayersSJFormulaShort = Catalog.GetString("Peak power") + " SJ (Sayers, 1999)";
+	public static string PotencySayersSJFormula = PotencySayersSJFormulaShort + "\n" +
 		"(60.7*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (45.3*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -2055";
 	
-	public static string PotencySayersCMJFormula = Catalog.GetString("Peak power") + " CMJ (Sayers, 1999) \n" +
+	public static string PotencySayersCMJFormulaShort = Catalog.GetString("Peak power") + " CMJ (Sayers, 1999)";
+	public static string PotencySayersCMJFormula = PotencySayersCMJFormulaShort + "\n" +
 		"(51.9*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (48.9*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -2007";
 	
-	public static string PotencyShettyFormula = Catalog.GetString("Peak power") + " (Shetty, 2002) \n" +
+	public static string PotencyShettyFormulaShort = Catalog.GetString("Peak power") + " (Shetty, 2002)";
+	public static string PotencyShettyFormula = PotencyShettyFormulaShort + "\n" +
 		"(1925.72*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (14.74*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -66.3";
 	
-	public static string PotencyCanavanFormula = Catalog.GetString("Peak power") + " (Canavan, 2004) \n" +
+	public static string PotencyCanavanFormulaShort = Catalog.GetString("Peak power") + " (Canavan, 2004)";
+	public static string PotencyCanavanFormula = PotencyCanavanFormulaShort + "\n" +
 		"(65.1*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (25.8*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -1413.1";
 	
@@ -197,27 +209,42 @@ public class Constants
 		")) -(15.3*" + Catalog.GetString("height") + "(cm)) -1413.1";
 	*/ //what is this height?
 	
-	public static string PotencyLaraMaleApplicantsSCFormula = Catalog.GetString("Peak power") + " (Lara, 2006, " + Catalog.GetString("Male applicants to a Faculty of Sport Sciencies") + ") \n" +
+	public static string PotencyLaraMaleApplicantsSCFormulaShort = 
+		Catalog.GetString("Peak power") + " (Lara, 2006, m)";
+	public static string PotencyLaraMaleApplicantsSCFormula = PotencyLaraMaleApplicantsSCFormulaShort + 
+		" (" + Catalog.GetString("Male applicants to a Faculty of Sport Sciencies") + ") \n" +
 		"(62.5*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (50.3*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -2184.7";
 	
-	public static string PotencyLaraFemaleEliteVoleiFormula = Catalog.GetString("Peak power") + " (Lara, 2006, " + Catalog.GetString("Female elite volleybol") + ") \n" +
+	public static string PotencyLaraFemaleEliteVoleiFormulaShort = 
+		Catalog.GetString("Peak power") + " (Lara, 2006, fev)"; 
+	public static string PotencyLaraFemaleEliteVoleiFormula = PotencyLaraFemaleEliteVoleiFormulaShort + 
+		" (" + Catalog.GetString("Female elite volleybol") + ") \n" +
 		"(83.1*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (42*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -2488";
 	
-	public static string PotencyLaraFemaleMediumVoleiFormula = Catalog.GetString("Peak power") + " (Lara, 2006, " + Catalog.GetString("Female medium volleybol") + ") \n" +
+	public static string PotencyLaraFemaleMediumVoleiFormulaShort = 
+		Catalog.GetString("Peak power") + " (Lara, 2006, fmv)";
+	public static string PotencyLaraFemaleMediumVoleiFormula = PotencyLaraFemaleMediumVoleiFormulaShort +
+		" (" + Catalog.GetString("Female medium volleybol") + ") \n" +
 		"(53.6*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (67.5*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -2624.1";
 	
-	public static string PotencyLaraFemaleSCStudentsFormula = Catalog.GetString("Peak power") + " (Lara, 2006, " + Catalog.GetString("Female sports sciencies students") + ") \n" +
+	public static string PotencyLaraFemaleSCStudentsFormulaShort = 
+		Catalog.GetString("Peak power") + " (Lara, 2006, fsc)";
+	public static string PotencyLaraFemaleSCStudentsFormula = PotencyLaraFemaleSCStudentsFormulaShort +
+		" (" + Catalog.GetString("Peak power") + " (Lara, 2006, " + 
+		Catalog.GetString("Female sports sciencies students") + ") \n" +
 		"(56.7*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (47.2*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -1772.6";
 	
-	public static string PotencyLaraFemaleSedentaryFormula = Catalog.GetString("Peak power") + " (Lara, 2006, " + Catalog.GetString("Female university students") + ") \n" +
+	public static string PotencyLaraFemaleSedentaryFormulaShort = Catalog.GetString("Peak power") + " (Lara, 2006, fu)";
+	public static string PotencyLaraFemaleSedentaryFormula = PotencyLaraFemaleSedentaryFormulaShort +
+		" (" + Catalog.GetString("Peak power") + " (Lara, 2006, " + Catalog.GetString("Female university students") + ") \n" +
 		"(68.2*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (40.8*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -1731.1";
 	
-	public static string RJPotencyBoscoFormula = "Peak Power" + " (Bosco)" + "\n 9.81^2*TF*TT / (4*jumps*(TT-TF))";
+	public static string RJPotencyBoscoFormula = "Peak Power" + " (Bosco)" + " 9.81^2*TF*TT / (4*jumps*(TT-TF))";
 	public static string RJPotencyBoscoFormulaOnly = "9.81*9.81 * tvavg*jumps * time / ( 4.0 * jumps * (time - tvavg*jumps) )"; //*4.0 for having double division
 	public static string RJPotencyBoscoName = Catalog.GetString("Peak Power") + " (Bosco)";
 
@@ -233,9 +260,11 @@ public class Constants
 	//global stat types
 	public static string TypeSessionSummary = Catalog.GetString("Session summary");
 	public static string TypeJumperSummary = Catalog.GetString("Jumper summary");
-	public static string TypeJumpsSimple = Catalog.GetString("Jumps: Simple");
-	public static string TypeJumpsSimpleWithTC = Catalog.GetString("Jumps: Simple with TC");
+	public static string TypeJumpsSimple = Catalog.GetString("Simple");
+	public static string TypeJumpsSimpleWithTC = Catalog.GetString("Simple with TC");
 	public static string TypeJumpsReactive = Catalog.GetString("Jumps: Reactive");
+	public static string TypeRunsSimple = Catalog.GetString("Runs: Simple");
+	public static string TypeRunsIntervallic = Catalog.GetString("Runs: Intervallic");
 
 	//strings
 	public static string AllJumpsName = Catalog.GetString("See all jumps");
@@ -271,6 +300,18 @@ public class Constants
 	//public static string FileNameZoomOutIcon = "gtk-zoom-out.png";
 	public static string FileNameZoomInIcon = "gtk-zoom-in.png";
 	public static string FileNameZoomInWithTextIcon = "gtk-zoom-in-with-text.png";
+	public static string FileNameNew1 = "gtk-new-1.png";
+	public static string FileNameNewPlus = "gtk-new-plus.png";
+	public static string FileNameOpen1 = "gtk-open-1.png";
+	public static string FileNameOpenPlus = "gtk-open-plus.png";
+
+	public static string FileNameJumps = "stock_up.png";
+	public static string FileNameJumpsRJ = "stock_up_down.png";
+	public static string FileNameRuns = "stock_right.png";
+	public static string FileNameRunsInterval = "stock_right_left.png";
+	public static string FileNameReactionTime = "reaction_time_menu.png";
+	public static string FileNamePulse = "pulse_menu.png";
+	public static string FileNameMultiChronopic = "multichronopic_menu.png";
 	
 	public static string FileNameChronopic1 = "chronopic1.jpg";
 	public static string FileNameChronopic2 = "chronopic2.jpg";
@@ -280,6 +321,7 @@ public class Constants
 	public static string FileNameInfrared = "infrared.jpg";
 	
 	//30 colors defined
+	//see als UtilGtk that's not used by the server
 	public static string [] Colors = {
 		"Blue", "Coral", "Cyan", "Gray", "Green", "Pink", "Salmon", "Yellow",
 		"DarkBlue", "DarkCyan", "DarkGoldenrod", "DarkGray", 
@@ -387,7 +429,11 @@ public class Constants
 	};
 	
 	public static int Simulated = -1; 
-	public static string SimulatedMessage = Catalog.GetString("Tests are SIMULATED until Chronopic is connected at menu 'Tools / Chronopic'.");
+	public static string SimulatedMessage = Catalog.GetString("Tests are SIMULATED until Chronopic is connected.");
+	public static string SimulatedTreeview = " (" + Catalog.GetString("Simulated") + ")"; 
+	
+	public static string ChronopicOne = Catalog.GetString("All tests available except MultiChronopic.");
+	public static string ChronopicMore = Catalog.GetString("All tests available.");
 
 	
 	//levels of sport practice
@@ -458,5 +504,29 @@ public class Constants
 	}
 	
 	public const string PrefVersionAvailable = "versionAvailable";
-
+	
+	/*
+	MultimediaStorage
+	BYSESSION samples:
+	Chronojump/multimedia/videos/sessionID/JUMP-jumpID
+	Chronojump/multimedia/photos/sessionID/RUN_I-runIntervalID
+	//see Constants.TestTypes 
+	*/
+	public enum MultimediaStorage {
+		BYSESSION
+	}
+	
+	public enum MultimediaItems {
+		PHOTO, VIDEO
+	}
+	public const string ExtensionVideo = ".avi";
+	public const string ExtensionPhoto = ".jpg";
+	public const string SmallPhotoDir = "small";
+	public static string MultimediaFileNoExists = Catalog.GetString("Sorry, this multimedia file does not exists.");
+	public static string PhotoTemp = "chronojump-last-photo";
+	public static string PhotoSmallTemp = "chronojump-last-photo-small";
+	public static string VideoTemp = "chronojump-last-video";
+	
+	public static string RunStartInitialSpeedYes = Catalog.GetString("Running start. Started with initial speed.");
+	public static string RunStartInitialSpeedNo = Catalog.GetString("Standing start. Started without initial speed.");
 }
