@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2011   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -40,21 +40,26 @@ public class ReactionTimeExecute : EventExecute
 	}
 
 	//reactionTime execution
-	public ReactionTimeExecute(EventExecuteWindow eventExecuteWin, int personID, string personName, int sessionID,   
-			Chronopic cp, Gtk.Statusbar appbar, Gtk.Window app, int pDN, bool volumeOn)
+	public ReactionTimeExecute(int personID, string personName, int sessionID,   
+			Chronopic cp, Gtk.TextView event_execute_textview_message, Gtk.Window app, int pDN, bool volumeOn,
+			double progressbarLimit, ExecutingGraphData egd 
+			)
 	{
-		this.eventExecuteWin = eventExecuteWin;
 		this.personID = personID;
 		this.personName = personName;
 		this.sessionID = sessionID;
 		
 		this.cp = cp;
-		this.appbar = appbar;
+		this.event_execute_textview_message = event_execute_textview_message;
 		this.app = app;
 
 		this.pDN = pDN;
 		this.volumeOn = volumeOn;
+		this.progressbarLimit = progressbarLimit;
+		this.egd = egd;
 	
+		fakeButtonUpdateGraph = new Gtk.Button();
+		fakeButtonEventEnded = new Gtk.Button();
 		fakeButtonFinished = new Gtk.Button();
 		
 		simulated = false;
@@ -87,6 +92,9 @@ public class ReactionTimeExecute : EventExecute
 	
 	public override void Manage()
 	{
+		//boolean to know if chronopic has been disconnected	
+		chronopicDisconnected = false;
+
 		if (simulated) 
 			platformState = Chronopic.Plataforma.ON;
 		else
@@ -94,8 +102,8 @@ public class ReactionTimeExecute : EventExecute
 		
 		
 		if (platformState==Chronopic.Plataforma.ON) {
-			appbar.Push( 1,Catalog.GetString("You are IN, RELEASE when prepared!!") );
-
+			feedbackMessage = Catalog.GetString("You are IN, RELEASE when prepared!");
+			needShowFeedbackMessage = true; 
 			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn);
 
 			loggedState = States.ON;
@@ -115,7 +123,7 @@ public class ReactionTimeExecute : EventExecute
 			GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
 			thread.Start(); 
 		} 
-		else {
+		else if (platformState==Chronopic.Plataforma.OFF) {
 			ConfirmWindow confirmWin;		
 			confirmWin = ConfirmWindow.Show( 
 					Catalog.GetString("You are OUT, come inside and press the 'accept' button"), "", "");
@@ -128,6 +136,9 @@ public class ReactionTimeExecute : EventExecute
 			//if confirmWin.Button_cancel is pressed retuen
 			confirmWin.Button_cancel.Clicked += new EventHandler(cancel_event_before_start);
 		}
+		else { //UNKNOW (Chronopic disconnected, port changed, ...)
+			chronopicHasBeenDisconnected();
+		}
 	}
 
 	
@@ -149,8 +160,6 @@ public class ReactionTimeExecute : EventExecute
 				if (platformState == Chronopic.Plataforma.ON && loggedState == States.OFF) 
 				{
 					//has landed
-Log.Write("w1 ");				
-
 					if(simulated)
 						timestamp = simulatedTimeLast * 1000; //conversion to milliseconds
 
@@ -164,8 +173,7 @@ Log.Write("w1 ");
 					//update event progressbar
 					double percentageToPass = 2; //has two phases
 
-Log.Write("w5 ");			
-					//eventExecuteWin.ProgressBarEventOrTimePreExecution(
+					//progressBarEventOrTimePreExecution(
 					//don't do it, put a boolean value and let the PulseGTK do it
 					updateProgressBar = new UpdateProgressBar (
 							true, //isEvent
@@ -173,7 +181,6 @@ Log.Write("w5 ");
 							percentageToPass
 							);
 					needUpdateEventProgressBar = true;
-Log.Write("w6 ");				
 
 					loggedState = States.ON;
 				}
@@ -182,13 +189,13 @@ Log.Write("w6 ");
 			
 					//it's out, was inside (= has released)
 					
-Log.Write("w9 ");				
 					initializeTimer();
 						
-Log.Write("wa ");				
+					feedbackMessage = "";
+					needShowFeedbackMessage = true; 
 						
 					//update event progressbar
-					//eventExecuteWin.ProgressBarEventOrTimePreExecution(
+					//progressBarEventOrTimePreExecution(
 					//don't do it, put a boolean value and let the PulseGTK do it
 					updateProgressBar = new UpdateProgressBar (
 							true, //isEvent
@@ -196,7 +203,6 @@ Log.Write("wa ");
 							1 //normal jump, phase 1/2
 							);
 					needUpdateEventProgressBar = true;
-Log.Write("wb ");				
 
 					//change the automata state
 					loggedState = States.OFF;
@@ -221,7 +227,7 @@ Log.Write("wb ");
 	
 	protected override void updateTimeProgressBar() {
 		//has no finished, but move progressbar time
-		eventExecuteWin.ProgressBarEventOrTimePreExecution(
+		progressBarEventOrTimePreExecution(
 				false, //isEvent false: time
 				false, //activity mode
 				-1	//don't want to show info on label
@@ -230,14 +236,17 @@ Log.Write("wb ");
 
 	protected override void write()
 	{
+		/*
 		string myStringPush =   
 			personName + " " + 
 			type + " " + Catalog.GetString("Time") + ": " + Util.TrimDecimals( time.ToString(), pDN ) ;
+		*/
 		
 		if(simulated)
-			appbar.Push(1, Constants.SimulatedMessage);
+			feedbackMessage = Catalog.GetString(Constants.SimulatedMessage);
 		else
-			appbar.Push( 1,myStringPush );
+			feedbackMessage = "";
+		needShowFeedbackMessage = true; 
 
 		uniqueID = SqliteReactionTime.Insert(
 				false, Constants.ReactionTimeTable, 
@@ -250,12 +259,11 @@ Log.Write("wb ");
 		//event will be raised, and managed in chronojump.cs
 		fakeButtonFinished.Click();
 		
-		//eventExecuteWin.PrepareJumpSimpleGraph(tv, tc);
-		prepareEventGraphReactionTime = new PrepareEventGraphReactionTime(time);
+		//app1.PrepareJumpSimpleGraph(tv, tc);
+		PrepareEventGraphReactionTimeObject = new PrepareEventGraphReactionTime(time);
 		needUpdateGraphType = eventType.REACTIONTIME;
 		needUpdateGraph = true;
 		
-		//eventExecuteWin.EventEnded();
 		needEndEvent = true; //used for hiding some buttons on eventWindow
 	}
 	
