@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2011   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -29,11 +29,8 @@ public class RunExecute : EventExecute
 {
 	protected double distance;
 	protected double time;
-
-	//for not checking always in database
 	protected bool startIn;
 	
-	
 	protected Chronopic cp;
 	//private Chronopic cp; //thi doesn't work
 	protected bool metersSecondsPreferred;
@@ -51,23 +48,28 @@ public class RunExecute : EventExecute
 	}
 
 	//run execution
-	public RunExecute(EventExecuteWindow eventExecuteWin, int personID, int sessionID, string type, double distance,   
-			Chronopic cp, Gtk.Statusbar appbar, Gtk.Window app, int pDN, bool metersSecondsPreferred, bool volumeOn)
+	public RunExecute(int personID, int sessionID, string type, double distance,   
+			Chronopic cp, Gtk.TextView event_execute_textview_message, Gtk.Window app, int pDN, bool metersSecondsPreferred, bool volumeOn,
+			double progressbarLimit, ExecutingGraphData egd 
+			)
 	{
-		this.eventExecuteWin = eventExecuteWin;
 		this.personID = personID;
 		this.sessionID = sessionID;
 		this.type = type;
 		this.distance = distance;
 		
 		this.cp = cp;
-		this.appbar = appbar;
+		this.event_execute_textview_message = event_execute_textview_message;
 		this.app = app;
 
 		this.pDN = pDN;
 		this.metersSecondsPreferred = metersSecondsPreferred;
 		this.volumeOn = volumeOn;
+		this.progressbarLimit = progressbarLimit;
+		this.egd = egd;
 		
+		fakeButtonUpdateGraph = new Gtk.Button();
+		fakeButtonEventEnded = new Gtk.Button();
 		fakeButtonFinished = new Gtk.Button();
 
 		simulated = false;
@@ -98,6 +100,10 @@ public class RunExecute : EventExecute
 	public override void Manage()
 	{
 Log.WriteLine("MANAGE!!!!");
+			
+		//boolean to know if chronopic has been disconnected	
+		chronopicDisconnected = false;
+
 		if (simulated) 
 			platformState = Chronopic.Plataforma.ON;
 		else
@@ -108,20 +114,27 @@ Log.WriteLine("MANAGE(b)!!!!");
 		//you can start ON or OFF the platform, 
 		//we record always de TF (or time between we abandonate the platform since we arrive)
 		if (platformState==Chronopic.Plataforma.ON) {
-			appbar.Push( 1,Catalog.GetString("You are IN, RUN when prepared!!") );
+			feedbackMessage = Catalog.GetString("You are IN, RUN when prepared!");
+			needShowFeedbackMessage = true; 
 			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn);
 
 			loggedState = States.ON;
 			startIn = true;
 			runPhase = runPhases.PLATFORM_INI;
-		} else {
-			appbar.Push( 1,Catalog.GetString("You are OUT, RUN when prepared!!") );
+		} else if (platformState==Chronopic.Plataforma.OFF) {
+			feedbackMessage = Catalog.GetString("You are OUT, RUN when prepared!");
+			needShowFeedbackMessage = true; 
 			Util.PlaySound(Constants.SoundTypes.CAN_START, volumeOn);
 
 			loggedState = States.OFF;
 			startIn = false;
 			runPhase = runPhases.PRE_RUNNING;
 		}
+		else { //UNKNOW (Chronopic disconnected, port changed, ...)
+			chronopicHasBeenDisconnected();
+			return;
+		}
+
 	
 		if (simulated) {
 			if(startIn) {
@@ -149,6 +162,7 @@ Log.WriteLine("MANAGE(b)!!!!");
 		cancel = false;
 		totallyCancelled = false;
 
+
 Log.WriteLine("MANAGE(2)!!!!");
 		//start thread
 		thread = new Thread(new ThreadStart(waitEvent));
@@ -214,7 +228,7 @@ Log.WriteLine("MANAGE(3)!!!!");
 					//don't record time
 						
 					initializeTimer();
-
+						
 					//update event progressbar
 					updateProgressBar = new UpdateProgressBar (
 							true, //isEvent
@@ -223,6 +237,9 @@ Log.WriteLine("MANAGE(3)!!!!");
 							);  
 					needUpdateEventProgressBar = true;
 					
+					feedbackMessage = "";
+					needShowFeedbackMessage = true; 
+					
 					//change the automata state
 					loggedState = States.OFF;
 						
@@ -274,7 +291,7 @@ Log.WriteLine("MANAGE(3)!!!!");
 				
 		
 		//has no finished, but move progressbar time
-		eventExecuteWin.ProgressBarEventOrTimePreExecution(
+		progressBarEventOrTimePreExecution(
 				false, //isEvent false: time
 				false, //activity mode
 				myTimeValue
@@ -285,13 +302,16 @@ Log.WriteLine("MANAGE(3)!!!!");
 	{
 		Log.WriteLine(string.Format("TIME: {0}", time.ToString()));
 		
+		/*
 		string myStringPush =   Catalog.GetString("Last run") + ": " + RunnerName + " " + 
 			type + " " + Catalog.GetString("time") + ": " + Util.TrimDecimals( time.ToString(), pDN ) + 
 			" " + Catalog.GetString("speed") + ": " + Util.TrimDecimals ( (distance/time).ToString(), pDN );
+		*/
 		if(simulated)
-			appbar.Push(1, Constants.SimulatedMessage);
+			feedbackMessage = Catalog.GetString(Constants.SimulatedMessage);
 		else
-			appbar.Push( 1,myStringPush );
+			feedbackMessage = "";
+		needShowFeedbackMessage = true; 
 
 
 		string description = "";
@@ -299,7 +319,7 @@ Log.WriteLine("MANAGE(3)!!!!");
 			// P = W * 9.8 * D / t   
 			// W: person weight
 			// D: distance between 3d and 9th stair
-			double weight = SqlitePersonSession.SelectAttribute(personID, sessionID, Constants.Weight);
+			double weight = SqlitePersonSession.SelectAttribute(false, personID, sessionID, Constants.Weight);
 			double distanceMeters = distance / 1000;
 			description = "P = " + Util.TrimDecimals ( (weight * 9.8 * distanceMeters / time).ToString(), pDN) + " (Watts)";
 		} else if(type == "Gesell-DBT") 
@@ -307,21 +327,22 @@ Log.WriteLine("MANAGE(3)!!!!");
 
 		uniqueID = SqliteRun.Insert(false, Constants.RunTable, "NULL", personID, sessionID, 
 				type, distance, time, description, 
-				Util.BoolToNegativeInt(simulated)); 
+				Util.BoolToNegativeInt(simulated), 
+				!startIn	//initialSpeed true if not startIn
+				); 
 		
 		//define the created object
-		eventDone = new Run(uniqueID, personID, sessionID, type, distance, time, description, Util.BoolToNegativeInt(simulated)); 
+		eventDone = new Run(uniqueID, personID, sessionID, type, distance, time, description, Util.BoolToNegativeInt(simulated), !startIn); 
 		
 		
 		//event will be raised, and managed in chronojump.cs
 		fakeButtonFinished.Click();
 		
-		//eventExecuteWin.PrepareRunSimpleGraph(time, distance/time);
-		prepareEventGraphRunSimple = new PrepareEventGraphRunSimple(time, distance/time);
+		//app1.PrepareRunSimpleGraph(time, distance/time);
+		PrepareEventGraphRunSimpleObject = new PrepareEventGraphRunSimple(time, distance/time);
 		needUpdateGraphType = eventType.RUN;
 		needUpdateGraph = true;
 		
-		//eventExecuteWin.EventEnded();
 		needEndEvent = true; //used for hiding some buttons on eventWindow
 	}
 
@@ -356,11 +377,12 @@ public class RunIntervalExecute : RunExecute
 	}
 
 	//run execution
-	public RunIntervalExecute(EventExecuteWindow eventExecuteWin, int personID, int sessionID, string type, double distanceInterval, double limitAsDouble, bool tracksLimited,  
-			Chronopic cp, Gtk.Statusbar appbar, Gtk.Window app, int pDN, bool metersSecondsPreferred, 
-			bool volumeOn, RepetitiveConditionsWindow repetitiveConditionsWin)
+	public RunIntervalExecute(int personID, int sessionID, string type, double distanceInterval, double limitAsDouble, bool tracksLimited,  
+			Chronopic cp, Gtk.TextView event_execute_textview_message, Gtk.Window app, int pDN, bool metersSecondsPreferred, 
+			bool volumeOn, RepetitiveConditionsWindow repetitiveConditionsWin,
+			double progressbarLimit, ExecutingGraphData egd 
+			)
 	{
-		this.eventExecuteWin = eventExecuteWin;
 		this.personID = personID;
 		this.sessionID = sessionID;
 		this.type = type;
@@ -384,14 +406,18 @@ public class RunIntervalExecute : RunExecute
 		
 		
 		this.cp = cp;
-		this.appbar = appbar;
+		this.event_execute_textview_message = event_execute_textview_message;
 		this.app = app;
 
 		this.metersSecondsPreferred = metersSecondsPreferred;
 		this.pDN = pDN;
 		this.volumeOn = volumeOn;
 		this.repetitiveConditionsWin = repetitiveConditionsWin;
+		this.progressbarLimit = progressbarLimit;
+		this.egd = egd;
 	
+		fakeButtonUpdateGraph = new Gtk.Button();
+		fakeButtonEventEnded = new Gtk.Button();
 		fakeButtonFinished = new Gtk.Button();
 
 		simulated = false;
@@ -449,6 +475,9 @@ public class RunIntervalExecute : RunExecute
 						runPhase = runPhases.RUNNING;
 						//run starts
 						initializeTimer();
+					
+						feedbackMessage = "";
+						needShowFeedbackMessage = true; 
 					}
 					else {
 						runPhase = runPhases.RUNNING;
@@ -478,7 +507,7 @@ public class RunIntervalExecute : RunExecute
 							distanceTotal = Util.GetRunITotalDistance(distanceInterval, distancesString, tracks);
 
 							//update graph
-							prepareEventGraphRunInterval = new PrepareEventGraphRunInterval(
+							PrepareEventGraphRunIntervalObject = new PrepareEventGraphRunInterval(
 									distanceIntervalFixed, myRaceTime, intervalTimesString, distanceTotal, distancesString);
 
 							needUpdateGraphType = eventType.RUNINTERVAL;
@@ -520,7 +549,7 @@ public class RunIntervalExecute : RunExecute
 									runPhase = runPhases.PLATFORM_END;
 								}
 								
-								//eventExecuteWin.ProgressBarEventOrTimePreExecution(
+								//progressBarEventOrTimePreExecution(
 								updateProgressBar= new UpdateProgressBar (
 										true, //isEvent
 										true, //tracksLimited: percentageMode
@@ -531,7 +560,7 @@ public class RunIntervalExecute : RunExecute
 								distanceTotal = Util.GetRunITotalDistance(distanceInterval, distancesString, tracks);
 							
 								//update graph
-								prepareEventGraphRunInterval = new PrepareEventGraphRunInterval(
+								PrepareEventGraphRunIntervalObject = new PrepareEventGraphRunInterval(
 										distanceIntervalFixed, myRaceTime, intervalTimesString, distanceTotal, distancesString);
 
 								needUpdateGraphType = eventType.RUNINTERVAL;
@@ -585,7 +614,7 @@ public class RunIntervalExecute : RunExecute
 								distanceTotal = Util.GetRunITotalDistance(distanceInterval, distancesString, tracks);
 							
 								//update graph
-								prepareEventGraphRunInterval = new PrepareEventGraphRunInterval(
+								PrepareEventGraphRunIntervalObject = new PrepareEventGraphRunInterval(
 										distanceIntervalFixed, myRaceTime, intervalTimesString, distanceTotal, distancesString);
 
 								needUpdateGraphType = eventType.RUNINTERVAL;
@@ -605,6 +634,9 @@ public class RunIntervalExecute : RunExecute
 						//run starts
 						initializeTimer();
 						lastTc = 0;
+
+						feedbackMessage = "";
+						needShowFeedbackMessage = true; 
 					} else
 						lastTc = timestamp/1000.0;
 						
@@ -651,7 +683,7 @@ public class RunIntervalExecute : RunExecute
 	}
 	
 	protected override void updateProgressBarForFinish() {
-		eventExecuteWin.ProgressBarEventOrTimePreExecution(
+		progressBarEventOrTimePreExecution(
 				false, //isEvent false: time
 				true, //percentageMode: it has finished, show bar at 100%
 				limitAsDouble
@@ -692,7 +724,7 @@ public class RunIntervalExecute : RunExecute
 				break;
 		}
 				
-		eventExecuteWin.ProgressBarEventOrTimePreExecution(
+		progressBarEventOrTimePreExecution(
 				false, //isEvent false: time
 				//!tracksLimited, //if tracksLimited: activity, if timeLimited: fraction
 				percentageMode,
@@ -771,7 +803,8 @@ public class RunIntervalExecute : RunExecute
 					distanceInterval, intervalTimesString, tracks, 
 					description,
 					limitString,
-					Util.BoolToNegativeInt(simulated) 
+					Util.BoolToNegativeInt(simulated),
+					!startIn	//initialSpeed true if not startIn
 					);
 		else {
 			uniqueID = SqliteRunInterval.Insert(false, Constants.RunIntervalTable, "NULL", personID, sessionID, type, 
@@ -779,11 +812,12 @@ public class RunIntervalExecute : RunExecute
 					distanceInterval, intervalTimesString, tracks, 
 					description,
 					limitString,
-					Util.BoolToNegativeInt(simulated) 
+					Util.BoolToNegativeInt(simulated),
+					!startIn
 					);
 
 			//define the created object
-			eventDone = new RunInterval(uniqueID, personID, sessionID, type, distanceTotal, timeTotal, distanceInterval, intervalTimesString, tracks, description, limitString, Util.BoolToNegativeInt(simulated)); 
+			eventDone = new RunInterval(uniqueID, personID, sessionID, type, distanceTotal, timeTotal, distanceInterval, intervalTimesString, tracks, description, limitString, Util.BoolToNegativeInt(simulated), !startIn); 
 
 
 			string tempValuesString = "";
@@ -792,27 +826,29 @@ public class RunIntervalExecute : RunExecute
 			else
 				tempValuesString = " (" + distanceIntervalFixed + "x" + Util.TrimDecimals( timeTotal.ToString(), pDN) + "T), " + Catalog.GetString("Tracks") + ": " + tracks;
 
+			/*
 			string myStringPush =   Catalog.GetString("Last run") + ": " + RunnerName + ", " + 
 				type + tempValuesString + ", " +
 				Catalog.GetString("AVG Speed") + ": " + Util.TrimDecimals( 
 						Util.GetSpeed(distanceTotal.ToString(),
 							timeTotal.ToString(), metersSecondsPreferred )
 						, pDN ) ;
+			*/
 			if(simulated)
-				appbar.Push(1, Constants.SimulatedMessage);
+				feedbackMessage = Catalog.GetString(Constants.SimulatedMessage);
 			else
-				appbar.Push( 1,myStringPush );
+				feedbackMessage = "";
+			needShowFeedbackMessage = true; 
 
 
 			//event will be raised, and managed in chronojump.cs
 			fakeButtonFinished.Click();
 
-			prepareEventGraphRunInterval = new PrepareEventGraphRunInterval(
+			PrepareEventGraphRunIntervalObject = new PrepareEventGraphRunInterval(
 					distanceIntervalFixed, Util.GetLast(intervalTimesString), intervalTimesString, distanceTotal, distancesString);
 			needUpdateGraphType = eventType.RUNINTERVAL;
 			needUpdateGraph = true;
 
-			//eventExecuteWin.EventEnded();
 			needEndEvent = true; //used for hiding some buttons on eventWindow, and also for updateTimeProgressBar here
 		}		
 	}
