@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2011   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -39,7 +39,6 @@ public class ExportSession
 	protected Session mySession;
 	protected TextWriter writer;
 	protected static Gtk.Window app1;
-	protected static Gtk.Statusbar myAppbar;
 	protected string fileName;
 	
 	protected int prefsDigitsNumber;
@@ -51,12 +50,10 @@ public class ExportSession
 	public ExportSession() {
 	}
 
-	//public ExportSession(Session mySession, Gtk.Window app1, Gnome.AppBar mainAppbar) 
-	public ExportSession(Session mySession, Gtk.Window app1, Gtk.Statusbar mainAppbar, int prefsDigitsNumber) 
+	public ExportSession(Session mySession, Gtk.Window app1, int prefsDigitsNumber) 
 	{
 		this.mySession = mySession;
 		this.prefsDigitsNumber = prefsDigitsNumber;
-		myAppbar = mainAppbar;
 		
 		spreadsheetString = "";
 
@@ -117,7 +114,7 @@ public class ExportSession
 			Log.WriteLine("cancelled");
 			//report does not currently send the appBar reference
 			if(formatFile != "report") {
-				myAppbar.Push ( 1, Catalog.GetString ("Cancelled") );
+				new DialogMessage(Constants.MessageTypes.INFO, Catalog.GetString("Cancelled."));
 			}
 			fc.Hide ();
 			return ;
@@ -238,7 +235,7 @@ public class ExportSession
 				Catalog.GetString ("Sport") + ":" + Catalog.GetString("Speciallity") + ":" +
 				Catalog.GetString ("Level") + ":" + Catalog.GetString ("Comments")
 			   );
-		
+	
 		foreach (Person p in myPersons) {
 			PersonSession ps = SqlitePersonSession.Select(p.UniqueID, mySession.UniqueID);
 			string sportName = (SqliteSport.Select(ps.SportID)).Name;
@@ -290,10 +287,13 @@ public class ExportSession
 					Catalog.GetString("Simulated") 
 				  );
 
+
+			Sqlite.Open();
 			foreach (string jumpString in myJumps) {
 				string [] myStr = jumpString.Split(new char[] {':'});
 					
 				double personWeight = SqlitePersonSession.SelectAttribute(
+						true, 	//dbconOpened
 						Convert.ToInt32(myStr[2]),
 						Convert.ToInt32(myStr[3]),
 						Constants.Weight);
@@ -334,6 +334,8 @@ public class ExportSession
 						
 					   );
 			}
+			Sqlite.Close();
+
 			writeData(myData);
 			writeData("VERTICAL-SPACE");
 		}
@@ -349,6 +351,7 @@ public class ExportSession
 		if(myJumpsRj.Length > 0) 
 			printTitles(title); 
 
+		Sqlite.Open();
 		foreach (string jump in myJumpsRj) {
 			
 			if(showSubjumps) {
@@ -397,6 +400,7 @@ public class ExportSession
 				myWeight = Util.WeightFromPercentToKg(
 						Convert.ToDouble(myStr[8]), 
 						SqlitePersonSession.SelectAttribute(
+							true, 	//dbconOpened
 							Convert.ToInt32(myStr[2]),
 							Convert.ToInt32(myStr[3]),
 							Constants.Weight
@@ -464,6 +468,8 @@ public class ExportSession
 				writeData("VERTICAL-SPACE");
 			}
 		}
+		Sqlite.Close();
+
 		//if not showSubjumps write data at last for not having every row as TH
 		if(! showSubjumps) {
 			writeData(myData);
@@ -487,7 +493,8 @@ public class ExportSession
 					Catalog.GetString("Time") + ":" + 
 					Catalog.GetString("Speed") + ":" + 
 					Catalog.GetString("Description") + ":" +
-					Catalog.GetString("Simulated") );
+					Catalog.GetString("Simulated") + ":" +
+					Catalog.GetString("Initial Speed") );
 
 			foreach (string runString in myRuns) {
 				string [] myStr = runString.Split(new char[] {':'});
@@ -501,7 +508,9 @@ public class ExportSession
 						myStr[4] + ":" +  myStr[5] + ":" + 	//run.type, run.distance
 						Util.TrimDecimals(myStr[6], dec) + ":" +  	//run.time
 						speed + ":" + 				//speed in m/s (true)
-						Util.RemoveNewLine(myStr[7]) + ":" + Util.SimulatedTestNoYes(Convert.ToInt32(myStr[8])) //description, simulated
+						Util.RemoveNewLine(myStr[7]) + ":" + 	//description
+						Util.SimulatedTestNoYes(Convert.ToInt32(myStr[8])) + ":" + //simulated
+						Util.NoYes(Util.StringToBool(myStr[9]))	//initialSpeed
 					   );
 			}
 			writeData(myData);
@@ -539,20 +548,30 @@ public class ExportSession
 						Catalog.GetString("Tracks") + ":" + 
 						Catalog.GetString("Limited") + ":" +
 						Catalog.GetString("Description") + ":" +
-						Catalog.GetString("Simulated") );
+						Catalog.GetString("Simulated") + ":" +
+						Catalog.GetString("Initial Speed") );
 				isFirstHeader = false;
 			}
 
 			string [] myStr = runString.Split(new char[] {':'});
+
+			RunType myRunType = new RunType();
+			string myRunTypeString = myStr[4];
+			string myRunDistanceInterval = myStr[7];
+			if(myRunDistanceInterval == "-1" || myRunDistanceInterval == "-1.0") {
+				myRunType = SqliteRunIntervalType.SelectAndReturnRunIntervalType(myRunTypeString);
+			}
 			myData.Add (
 					myStr[2] + ":" +    			//personID
 					myStr[0] + ":" +  myStr[1] + ":" +  	//person.name, run.uniqueID
-					myStr[4] + ":" +  Util.TrimDecimals(myStr[5], dec) + ":" + 	//run.type, run.distancetotal
+					myRunTypeString + ":" +  Util.TrimDecimals(myStr[5], dec) + ":" + 	//run.type, run.distancetotal
 					Util.TrimDecimals(myStr[6], dec) + ":" +  		//run.timetotal
 					Util.TrimDecimals(Util.GetSpeed(myStr[5], myStr[6], true), dec) + ":" + 	//speed AVG in m/s(true)
 					myStr[7] + ":" + 	 	//run.distanceInterval
 					myStr[9] + ":" +  Util.GetLimitedRounded(myStr[11], dec) + ":" + 	//tracks, limited
-					Util.RemoveNewLine(myStr[10]) + ":" + Util.SimulatedTestNoYes(Convert.ToInt32(myStr[12]))	//description, simulated
+					Util.RemoveNewLine(myStr[10]) + ":" + 	//description
+					Util.SimulatedTestNoYes(Convert.ToInt32(myStr[12])) + ":" +	//simulated
+					Util.NoYes(Util.StringToBool(myStr[13]))	//initialSpeed
 				   );
 			
 			if(showSubruns) {
@@ -583,8 +602,16 @@ public class ExportSession
 				
 				int count = 1;
 				foreach(string myTime in timeString) {
-					myData.Add((count++).ToString() + ":" + 
-							Util.TrimDecimals(Util.GetSpeed(myStr[7], myTime, true), dec) + ":" + //true for: m/s
+					string myDistance = myStr[7];
+					string myShowDistance = "";
+					if(myRunDistanceInterval == "-1" || myRunDistanceInterval == "-1.0") {
+						myDistance = Util.GetRunIVariableDistancesStringRow(
+								myRunType.DistancesString, count -1).ToString();
+						myShowDistance = " (" + myDistance.ToString() + "m)";
+					}
+
+					myData.Add((count++).ToString() + myShowDistance + ":" + 
+							Util.TrimDecimals(Util.GetSpeed(myDistance, myTime, true), dec) + ":" + //true for: m/s
 							Util.TrimDecimals(myTime, dec)
 						  );
 				}
@@ -841,11 +868,10 @@ public class ExportSession
 public class ExportSessionCSV : ExportSession 
 {
 
-	public ExportSessionCSV(Session mySession, Gtk.Window app1, Gtk.Statusbar mainAppbar, int prefsDigitsNumber) 
+	public ExportSessionCSV(Session mySession, Gtk.Window app1, int prefsDigitsNumber) 
 	{
 		this.mySession = mySession;
 		this.prefsDigitsNumber = prefsDigitsNumber;
-		myAppbar = mainAppbar;
 	
 		spreadsheetString = "\n\n" + Catalog.GetString("When import from your spreadsheet (OpenOffice, R, MS Excel, ...)\nremember the separator character is semicolon: <b>;</b>");
 
@@ -881,7 +907,8 @@ public class ExportSessionCSV : ExportSession
 	protected override void printFooter()
 	{
 		Log.WriteLine( "Correctly exported" );
-		myAppbar.Push ( 1, Catalog.GetString ("Exported to file: ") + fileName );
+		string myString = Catalog.GetString ("Exported to file: ") + fileName;
+		new DialogMessage(Constants.MessageTypes.INFO, myString);
 	}
 	
 	~ExportSessionCSV() {}
@@ -891,13 +918,12 @@ public class ExportSessionXML : ExportSession
 {
 	private XmlTextWriter xr;
 		
-	public ExportSessionXML(Session mySession, Gtk.Window app1, Gtk.Statusbar mainAppbar, int prefsDigitsNumber) 
+	public ExportSessionXML(Session mySession, Gtk.Window app1, int prefsDigitsNumber) 
 	//public ExportXML(Session mySession, Gtk.Window app1) 
 	{
 		this.mySession = mySession;
 		this.prefsDigitsNumber = prefsDigitsNumber;
 		//this.app1 = app1;
-		myAppbar = mainAppbar;
 		
 		//xr = new XmlTextWriter(fileExport, null);
 		//xr.Formatting = Formatting.Indented;
