@@ -75,16 +75,24 @@ public class ChronopicWindow
 	[Widget] Gtk.Button button_connect_cp3;
 	[Widget] Gtk.Button button_connect_cp4;
 	
+	[Widget] Gtk.CheckButton checkbutton_multi_show;
+	[Widget] Gtk.Table table_multi_chronopic;
+	//[Widget] Gtk.Button button_reload;
+	
 	[Widget] Gtk.Image chronopic_image;
+	[Widget] Gtk.TextView textview_ports_found;
+	[Widget] Gtk.TextView textview_ports_found_explanation;
 
 	//chronopic connection thread
 	Thread thread;
 	bool needUpdateChronopicWin;
 	bool updateChronopicWinValuesState;
 	string updateChronopicWinValuesMessage;
+	//Gtk.Button fakeButtonCancelled;
 
 	[Widget] Gtk.Button fakeConnectionButton; //raised when chronopic detection ended
 	[Widget] Gtk.Button fakeWindowDone; //raised when chronopic detection ended
+	//[Widget] Gtk.Button fakeWindowReload; //raised when asked to reload
 
 	bool isWindows;	
 
@@ -151,8 +159,12 @@ public class ChronopicWindow
 	}
 	
 	//recreate is used when a Chronopic was disconnected
+	//port names com from gui/chronojump.cs to this method (myCpd)
 	static public ChronopicWindow Create (ArrayList myCpd, bool recreate, bool volumeOn)
 	{
+		if (ChronopicWindowBox != null && recreate) {
+			ChronopicWindowBox.chronopic_window.Hide();
+		}
 		if (ChronopicWindowBox == null || recreate) {
 			ChronopicWindowBox = new ChronopicWindow (myCpd);
 		}
@@ -163,6 +175,7 @@ public class ChronopicWindow
 		ChronopicWindowBox.volumeOn = volumeOn;
 
 		ChronopicWindowBox.fakeWindowDone = new Gtk.Button();
+		//ChronopicWindowBox.fakeWindowReload = new Gtk.Button();
 		
 		return ChronopicWindowBox;
 	}
@@ -171,17 +184,27 @@ public class ChronopicWindow
 	{
 		if (ChronopicWindowBox == null) {
 			ChronopicWindowBox = new ChronopicWindow (cpd);
-		}
+		} 
 		
 		ChronopicWindowBox.volumeOn = volumeOn;
 		ChronopicWindowBox.checkChronopicDisconnected();
 		ChronopicWindowBox.createCombos();
+
+		//findPorts only puts info on textview
+		//ports info comes from gui/chronojump.cs to Create mehod
+		ChronopicWindowBox.findPorts();
+
 		ChronopicWindowBox.chronopic_window.Show();
+		ChronopicWindowBox.chronopic_window.Present();
+Log.WriteLine("bbb");
 	
 		return ChronopicWindowBox;
 	}
 
 	private void setDefaultValues() {
+		checkbutton_multi_show.Active = false;
+		table_multi_chronopic.Visible = false;
+
 		if(isWindows) {
 			combo_linux1.Hide();
 			combo_linux2.Hide();
@@ -212,6 +235,8 @@ public class ChronopicWindow
 		image_cp2_yes.Hide();
 		image_cp3_yes.Hide();
 		image_cp4_yes.Hide();
+		
+		//fakeButtonCancelled = new Gtk.Button();
 	}
 	
 	//check if user has disconnected chronopic or port has changed
@@ -270,14 +295,16 @@ public class ChronopicWindow
 	//private void createComboWindows(string myPort, Gtk.ComboBox myCombo) {
 	private void createComboWindows() {
 		//combo port stuff
-		comboWindowsOptions = new string[257];
-		for (int i=1; i <= 257; i ++)
+		comboWindowsOptions = new string[32];
+		for (int i=1; i <= 32; i ++)
 			comboWindowsOptions[i-1] = "COM" + i;
+		string [] def = Util.StringToStringArray(Constants.ChronopicDefaultPortWindows);
+		string [] allWithDef = Util.AddArrayString(def, comboWindowsOptions);
 	
-		UtilGtk.ComboUpdate(combo_windows1, comboWindowsOptions, Constants.ChronopicDefaultPortWindows);
-		UtilGtk.ComboUpdate(combo_windows2, comboWindowsOptions, Constants.ChronopicDefaultPortWindows);
-		UtilGtk.ComboUpdate(combo_windows3, comboWindowsOptions, Constants.ChronopicDefaultPortWindows);
-		UtilGtk.ComboUpdate(combo_windows4, comboWindowsOptions, Constants.ChronopicDefaultPortWindows);
+		UtilGtk.ComboUpdate(combo_windows1, allWithDef, Constants.ChronopicDefaultPortWindows);
+		UtilGtk.ComboUpdate(combo_windows2, allWithDef, Constants.ChronopicDefaultPortWindows);
+		UtilGtk.ComboUpdate(combo_windows3, allWithDef, Constants.ChronopicDefaultPortWindows);
+		UtilGtk.ComboUpdate(combo_windows4, allWithDef, Constants.ChronopicDefaultPortWindows);
 				
 		foreach(ChronopicPortData a in cpd) {
 			if(a.Num == 1) {
@@ -371,6 +398,23 @@ public class ChronopicWindow
 		else if (o == combo_linux4 || o == combo_windows4) 
 			button_connect_cp4.Sensitive = portOk;
 	}
+	
+	private void findPorts() {
+		string saferPorts = "";
+		if(Util.IsWindows())
+			saferPorts =
+				"\n\n" + Catalog.GetString("COM3 use to be the correct port (if available).") + "\n" + 
+				Catalog.GetString("Ports above COM4 may not work.") + "\n" + 
+				Catalog.GetString("If you want a safer port, press help button and press 'Force Chronopic to port COM1 - COM4'.");
+
+		textview_ports_found.Buffer = UtilGtk.TextViewPrint(
+				Util.StringArrayToString(SerialPort.GetPortNames(),"\n"));
+		textview_ports_found_explanation.Buffer = UtilGtk.TextViewPrint(
+				Catalog.GetString("These are USB devices like Chronopic but also pendrives, USB printers...") + "\n" + 
+				Catalog.GetString("If you just plugged Chronopic cable and expected port is not listed, close and open again this window.") +
+				saferPorts
+				);
+	}
 
 	private void chronopicAtStart(object o, EventArgs args) {
 		//make active menuitem chronopic, and this
@@ -388,7 +432,7 @@ public class ChronopicWindow
 			return false;
 		}
 		//need to do this, if not it crashes because chronopicConnectionWin gets died by thread ending
-		ChronopicConnection chronopicConnectionWin = ChronopicConnection.Show();
+		chronopicConnectionWin = ChronopicConnection.Show();
 		chronopicConnectionWin.Pulse();
 		
 		Thread.Sleep (50);
@@ -412,11 +456,12 @@ public class ChronopicWindow
 	}
 
 	//chronopic init should not touch  gtk, for the threads
-	private Chronopic chronopicInit (Chronopic myCp, out SerialPort mySp, Chronopic.Plataforma myPS, string myPort, out string returnString, out bool success) 
+	//private Chronopic chronopicInit (out Chronopic myCp, out SerialPort mySp, Chronopic.Plataforma myPS, string myPort, out string returnString, out bool success) 
+	private void chronopicInit (out Chronopic myCp, out SerialPort mySp, Chronopic.Plataforma myPS, string myPort, out string returnString, out bool success) 
 	{
 		Log.WriteLine ( Catalog.GetString ("starting connection with chronopic") );
-		if(isWindows)
-			Log.WriteLine ( Catalog.GetString ("If you have previously used the modem via a serial port (in a GNU/Linux session, and you selected serial port), Chronojump will crash.") );
+		//if(isWindows)
+		//	Log.WriteLine ( Catalog.GetString ("If you have previously used the modem via a serial port (in a GNU/Linux session, and you selected serial port), Chronojump will crash.") );
 
 		success = true;
 		
@@ -428,29 +473,41 @@ public class ChronopicWindow
 			Log.WriteLine("chronopicInit-2");		
 			//-- Create chronopic object, for accessing chronopic
 			myCp = new Chronopic(mySp);
-
-			Log.WriteLine("chronopicInit-3");		
-			//on windows, this check make a crash 
-			//i think the problem is: as we don't really know the Timeout on Windows (.NET) and this variable is not defined on chronopic.cs
-			//the Read_platform comes too much soon (when cp is not totally created), and this makes crash
-
-			//-- Obtener el estado inicial de la plataforma
-
-			bool ok=false;
-			Log.WriteLine("chronopicInit-4");		
-			do {
-				Log.WriteLine("chronopicInit-5");		
-				ok=myCp.Read_platform(out myPS);
-				Log.WriteLine("chronopicInit-6");		
-			} while(!ok);
-			Log.WriteLine("chronopicInit-7");		
-			if (!ok) {
-				//-- Si hay error terminar
-				Log.WriteLine(string.Format("Error: {0}", myCp.Error));
+			
+			Log.WriteLine("chronopicInit-2.1");		
+			myCp.Flush();
+			
+			//if myCp has been cancelled
+			if(myCp.AbortFlush) {
+				Log.WriteLine("chronopicInit-2.2 cancelled");
 				success = false;
+				myCp = new Chronopic(); //fake constructor
+			} else {
+				Log.WriteLine("chronopicInit-3");		
+				//on windows, this check make a crash 
+				//i think the problem is: as we don't really know the Timeout on Windows (.NET) and this variable is not defined on chronopic.cs
+				//the Read_platform comes too much soon (when cp is not totally created), and this makes crash
+
+				//-- Obtener el estado inicial de la plataforma
+
+				bool ok=false;
+				Log.WriteLine("chronopicInit-4");		
+				do {
+					Log.WriteLine("chronopicInit-5");		
+					ok=myCp.Read_platform(out myPS);
+					Log.WriteLine("chronopicInit-6");		
+				} while(!ok);
+				Log.WriteLine("chronopicInit-7");		
+				if (!ok) {
+					//-- Si hay error terminar
+					Log.WriteLine(string.Format("Error: {0}", myCp.Error));
+					success = false;
+				}
 			}
 		} catch {
+			Log.WriteLine("chronopicInit-2.a catched");
 			success = false;
+			myCp = new Chronopic(); //fake constructor
 		}
 			
 		returnString = "";
@@ -458,16 +515,12 @@ public class ChronopicWindow
 			if(currentCp == 1)
 				connected = true;
 			returnString = string.Format(Catalog.GetString("<b>Connected</b> to Chronopic on port: {0}"), myPort);
-			//appbar2.Push( 1, returnString);
 		}
 		if(! success) {
 			returnString = Catalog.GetString("Problems communicating to chronopic.");
-			if(currentCp == 1) 
+			if(currentCp == 1) {
 				returnString += " " + Catalog.GetString("Changed platform to 'Simulated'");
-			if(isWindows) {
-				returnString += Catalog.GetString("\n\nOn Windows we recommend to remove and connect USB or serial cable from the computer after every unsuccessful port test.");
-				returnString += Catalog.GetString("\n... And after cancelling Chronopic detection.");
-				returnString += Catalog.GetString("\n\n... Later, when you close Chronojump it will probably get frozen. If this happens, let's press CTRL+C on the black screen.");
+				returnString += Catalog.GetString("\n\nWe recommend to remove and connect USB cable.");
 			}
 
 			//this will raise on_radiobutton_simulated_ativate and 
@@ -476,9 +529,12 @@ public class ChronopicWindow
 				connected = false;
 			}
 		}
-		return myCp;
+//		return myCp;
 	}
 	
+	private void on_checkbutton_multi_show_clicked(object o, EventArgs args) {
+		table_multi_chronopic.Visible = checkbutton_multi_show.Active;
+	}
 
 	private void on_button_connect_cp_clicked (object o, EventArgs args) {
 		if (o == null)
@@ -521,8 +577,7 @@ public class ChronopicWindow
 		Log.WriteLine("HELP");
 		new HelpPorts();
 	}
-
-
+	
 	public void SerialPortsClose() {
 		Console.WriteLine("Closing sp");
 		sp.Close();
@@ -530,21 +585,25 @@ public class ChronopicWindow
 
 
 	void prepareChronopicConnection() {
-		ChronopicConnection chronopicConnectionWin = ChronopicConnection.Show();
+		chronopicConnectionWin = ChronopicConnection.Show();
 		chronopicConnectionWin.LabelFeedBackReset();
 
-		chronopicConnectionWin.Button_cancel.Clicked += new EventHandler(on_chronopic_cancelled);
+//		chronopicConnectionWin.Button_cancel.Clicked += new EventHandler(on_chronopic_cancelled);
 		
 		fakeConnectionButton = new Gtk.Button();
 		fakeConnectionButton.Clicked += new EventHandler(on_chronopic_detection_ended);
 
+		needUpdateChronopicWin = false;
 		thread = new Thread(new ThreadStart(waitChronopicStart));
 		GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
 		thread.Start(); 
 	}
-	
+
+	static Chronopic cpDoing;	
 	protected void waitChronopicStart () 
 	{
+		chronopicConnectionWin.Button_cancel.Clicked += new EventHandler(on_chronopic_cancelled);
+
 		if(currentCp == 1) {
 		//	simulated = false;
 		//	SqlitePreferences.Update("simulated", simulated.ToString(), false);
@@ -562,7 +621,9 @@ public class ChronopicWindow
 			
 		if(currentCp == 1) {
 			myPort = ((ChronopicPortData) cpd[0]).Port;
-			cp = chronopicInit(cp, out sp, platformState, myPort, out message, out success);
+			cpDoing = cp;
+			chronopicInit(out cpDoing, out sp, platformState, myPort, out message, out success);
+			cp = cpDoing;
 			if(success) {
 				((ChronopicPortData) cpd[0]).Connected=true;
 				button_connect_cp1.Sensitive = false;
@@ -592,7 +653,9 @@ public class ChronopicWindow
 		}
 		else if(currentCp == 2) {
 			myPort = ((ChronopicPortData) cpd[1]).Port;
-			cp2 = chronopicInit(cp2, out sp2, platformState2, myPort, out message, out success);
+			cpDoing = cp2;
+			chronopicInit(out cpDoing, out sp2, platformState2, myPort, out message, out success);
+			cp2 = cpDoing;
 			if(success) {
 				((ChronopicPortData) cpd[1]).Connected=true;
 				button_connect_cp2.Sensitive = false;
@@ -618,7 +681,9 @@ public class ChronopicWindow
 		}
 		else if(currentCp == 3) {
 			myPort = ((ChronopicPortData) cpd[2]).Port;
-			cp3 = chronopicInit(cp3, out sp3, platformState3, myPort, out message, out success);
+			cpDoing = cp3;
+			chronopicInit(out cpDoing, out sp3, platformState3, myPort, out message, out success);
+			cp3 = cpDoing;
 			if(success) {
 				((ChronopicPortData) cpd[2]).Connected=true;
 				button_connect_cp3.Sensitive = false;
@@ -640,7 +705,9 @@ public class ChronopicWindow
 		}
 		else if(currentCp == 4) {
 			myPort = ((ChronopicPortData) cpd[3]).Port;
-			cp4 = chronopicInit(cp4, out sp4, platformState4, myPort, out message, out success);
+			cpDoing = cp4;
+			chronopicInit(out cpDoing, out sp4, platformState4, myPort, out message, out success);
+			cp4 = cpDoing;
 			if(success) {
 				((ChronopicPortData) cpd[3]).Connected=true;
 				button_connect_cp4.Sensitive = false;
@@ -670,6 +737,7 @@ public class ChronopicWindow
 		foreach(ChronopicPortData a in cpd)
 			Log.WriteLine(a.Num + ", " + a.Port + ", " + a.Connected);
 
+		fakeWindowDone.Click();
 		needUpdateChronopicWin = true;
 	}
 
@@ -680,14 +748,25 @@ public class ChronopicWindow
 
 	private void on_chronopic_cancelled (object o, EventArgs args) {
 		Log.WriteLine("cancelled-----");
+		//fakeButtonCancelled.Click(); //just to show message of crashing on windows exiting
 		
+		cpDoing.AbortFlush = true;
+
 		//kill the chronopicInit function that is waiting event 
-		thread.Abort();
+		//thread.Abort();
+		//http://stackoverflow.com/questions/2853072/thread-does-not-abort-on-application-closing
+		//Log.Write(thread.ThreadState.ToString());
+		//thread.IsBackground = true;
+		
+		//try to solve windows problems when a chronopic detection was cancelled
+		//Log.Write(thread.ThreadState.ToString());
+		//thread.Join(1000);
+		//Log.Write(thread.ThreadState.ToString());
+
 		
 		updateChronopicWinValuesState= false; //disconnected
 		updateChronopicWinValuesMessage= Catalog.GetString("Cancelled by user");
 		needUpdateChronopicWin = true;
-			
 	}
 	
 	void on_button_close_clicked (object o, EventArgs args)
@@ -697,6 +776,14 @@ public class ChronopicWindow
 		ChronopicWindowBox.chronopic_window.Hide();
 	}
 
+	/*	
+	private void on_button_reload_clicked (object o, EventArgs args) {
+		Log.WriteLine("RELOAD");
+		fakeWindowReload.Click();
+		//ChronopicWindowBox.chronopic_window.Hide();
+	}
+	*/
+
 	void on_delete_event (object o, DeleteEventArgs args)
 	{
 		//nice: this makes windows no destroyed, then it works like button_close
@@ -746,4 +833,15 @@ public class ChronopicWindow
 		get { return fakeWindowDone; }
 	}
 
+	/*	
+	public Button FakeWindowReload
+	{
+		get { return fakeWindowReload; }
+	}
+	*/
+
+	//public Gtk.Button FakeButtonCancelled {
+	//	get { return fakeButtonCancelled; }
+	//}
+
 }
