@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2009   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2011   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -35,7 +35,6 @@ using Mono.Unix;
 public class EditJumpWindow : EditEventWindow
 {
 	static EditJumpWindow EditJumpWindowBox;
-//	protected bool weightPercentPreferred;
 	protected double personWeight;
 	protected int sessionID; //for know weight specific to this session
 
@@ -63,6 +62,7 @@ public class EditJumpWindow : EditEventWindow
 
 		EditJumpWindowBox.weightPercentPreferred = weightPercentPreferred;
 		EditJumpWindowBox.personWeight = SqlitePersonSession.SelectAttribute(
+				false,
 				Convert.ToInt32(myEvent.PersonID),
 				Convert.ToInt32(myEvent.SessionID),
 				Constants.Weight); 
@@ -81,7 +81,9 @@ public class EditJumpWindow : EditEventWindow
 	}
 	
 	protected override void initializeValues () {
+		typeOfTest = Constants.TestTypes.JUMP;
 		showType = true;
+		showRunStart = false;
 		showTv = true;
 		showTc= true;
 		showFall = true;
@@ -94,9 +96,9 @@ public class EditJumpWindow : EditEventWindow
 		showMistakes = false;
 		
 		if(weightPercentPreferred)
-			label_weight_title.Text = label_weight_title.Text.ToString() + " %";
+			label_weight_units.Text = "%";
 		else
-			label_weight_title.Text = label_weight_title.Text.ToString() + " Kg";
+			label_weight_units.Text = "Kg";
 
 		Log.WriteLine(string.Format("-------------{0}", personWeight));
 	}
@@ -249,7 +251,7 @@ public class EditJumpWindow : EditEventWindow
 			else
 				jumpWeightInKg = Convert.ToDouble(entryWeight);
 			
-			double newPersonWeight = SqlitePersonSession.SelectAttribute(personID, mySessionID, Constants.Weight); 
+			double newPersonWeight = SqlitePersonSession.SelectAttribute(false, personID, mySessionID, Constants.Weight); 
 			//jumpPercentWeightForNewPerson = jumpWeightInKg * 100 / newPersonWeight; 
 			jumpPercentWeightForNewPerson = Util.WeightFromKgToPercent(jumpWeightInKg, newPersonWeight); 
 			Log.WriteLine(string.Format("oldPW: {0}, jWinKg {1}, newPW{2}, jWin%NewP{3}",
@@ -290,7 +292,7 @@ public class EditJumpRjWindow : EditJumpWindow
 
 		EditJumpRjWindowBox.weightPercentPreferred = weightPercentPreferred;
 		EditJumpRjWindowBox.personWeight = SqlitePersonSession.SelectAttribute(
-				myEvent.PersonID, myEvent.SessionID, Constants.Weight); 
+				false, myEvent.PersonID, myEvent.SessionID, Constants.Weight); 
 
 		EditJumpRjWindowBox.pDN = pDN;
 		
@@ -306,7 +308,9 @@ public class EditJumpRjWindow : EditJumpWindow
 	}
 	
 	protected override void initializeValues () {
+		typeOfTest = Constants.TestTypes.JUMP_RJ;
 		showType = true;
+		showRunStart = false;
 		showTv = false;
 		showTc = false;
 		showFall = true;
@@ -318,9 +322,9 @@ public class EditJumpRjWindow : EditJumpWindow
 		showMistakes = false;
 		
 		if(weightPercentPreferred)
-			label_weight_title.Text = label_weight_title.Text.ToString() + " %";
+			label_weight_units.Text = "%";
 		else
-			label_weight_title.Text = label_weight_title.Text.ToString() + " Kg";
+			label_weight_units.Text = "Kg";
 	}
 
 	protected override string [] findTypes(Event myEvent) {
@@ -477,10 +481,22 @@ public class RepairJumpRjWindow
 		if(myJumpType.FixedValue > 0) {
 			if(myJumpType.JumpsLimited) {
 				//if it's a jump type jumpsLimited with a fixed value, then don't allow the creation of more jumps, and respect the -1 at last TF if found
-				fixedString = string.Format(Catalog.GetString("\nThis jump type is fixed to {0} jumps, you cannot add more."), myJumpType.FixedValue);
+				fixedString = "\n" + string.Format(
+						Catalog.GetPluralString(
+							"This jump type is fixed to one jump.",
+							"This jump type is fixed to {0} jumps.",
+							Convert.ToInt32(myJumpType.FixedValue)),
+						myJumpType.FixedValue) +
+					Catalog.GetString("You cannot add more.");
 			} else {
 				//if it's a jump type timeLimited with a fixed value, then complain when the total time is higher
-				fixedString = string.Format(Catalog.GetString("\nThis jump type is fixed to {0} seconds, totaltime cannot be greater."), myJumpType.FixedValue);
+				fixedString = "\n" + string.Format(
+						Catalog.GetPluralString(
+							"This jump type is fixed to one second.",
+							"This jump type is fixed to {0} seconds.",
+							Convert.ToInt32(myJumpType.FixedValue)),
+						myJumpType.FixedValue) +
+					Catalog.GetString("You cannot add more.");
 			}
 		}
 		return jumpTypeString + startString + fixedString;
@@ -775,216 +791,451 @@ public class RepairJumpRjWindow
 
 //--------------------------------------------------------
 //---------------- jump extra WIDGET --------------------
+//---------------- in 0.9.3 included in main gui ---------
 //--------------------------------------------------------
 
-public class JumpExtraWindow 
+partial class ChronoJumpWindow
 {
-	[Widget] Gtk.Window jump_extra;
-	[Widget] Gtk.Label label_limit;
-	[Widget] Gtk.SpinButton spinbutton_limit;
-	[Widget] Gtk.Label label_limit_units;
-	[Widget] Gtk.SpinButton spinbutton_weight;
-	[Widget] Gtk.SpinButton spinbutton_fall;
-	[Widget] Gtk.Button button_accept;
-	[Widget] Gtk.RadioButton radiobutton_kg;
-	[Widget] Gtk.RadioButton radiobutton_weight;
-	[Widget] Gtk.Label label_weight;
-	[Widget] Gtk.Label label_fall;
-	[Widget] Gtk.Label label_cm;
+	//options jumps
+	[Widget] Gtk.SpinButton extra_window_jumps_spinbutton_weight;
+	[Widget] Gtk.SpinButton extra_window_jumps_spinbutton_fall;
+	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_kg;
+	[Widget] Gtk.RadioButton extra_window_jumps_radiobutton_weight;
+	[Widget] Gtk.Label extra_window_jumps_label_weight;
+	[Widget] Gtk.Label extra_window_jumps_label_fall;
+	[Widget] Gtk.Label extra_window_jumps_label_cm;
+	[Widget] Gtk.Label extra_window_jumps_label_dj_arms;
+	[Widget] Gtk.CheckButton extra_window_jumps_check_dj_arms;
+	[Widget] Gtk.Label extra_window_label_jumps_no_options;
 	
-	[Widget] Gtk.Label label_dj_arms;
-	[Widget] Gtk.CheckButton check_dj_arms;
+	//options jumps_rj
+	[Widget] Gtk.Label extra_window_jumps_rj_label_limit;
+	[Widget] Gtk.SpinButton extra_window_jumps_rj_spinbutton_limit;
+	[Widget] Gtk.Label extra_window_jumps_rj_label_limit_units;
+	[Widget] Gtk.SpinButton extra_window_jumps_rj_spinbutton_weight;
+	[Widget] Gtk.SpinButton extra_window_jumps_rj_spinbutton_fall;
+	[Widget] Gtk.RadioButton extra_window_jumps_rj_radiobutton_kg;
+	[Widget] Gtk.RadioButton extra_window_jumps_rj_radiobutton_weight;
+	[Widget] Gtk.Label extra_window_jumps_rj_label_weight;
+	[Widget] Gtk.Label extra_window_jumps_rj_label_fall;
+	[Widget] Gtk.Label extra_window_jumps_rj_label_cm;
+	[Widget] Gtk.Label extra_window_label_jumps_rj_no_options;
+
+	//labels notebook_execute	
+	[Widget] Gtk.Label label_extra_window_radio_jump_free;
+	[Widget] Gtk.Label label_extra_window_radio_jump_sj;
+	[Widget] Gtk.Label label_extra_window_radio_jump_sjl;
+	[Widget] Gtk.Label label_extra_window_radio_jump_cmj;
+	[Widget] Gtk.Label label_extra_window_radio_jump_cmjl;
+	[Widget] Gtk.Label label_extra_window_radio_jump_abk;
+	[Widget] Gtk.Label label_extra_window_radio_jump_dj;
+	[Widget] Gtk.Label label_extra_window_radio_jump_rocket;
+	[Widget] Gtk.Label label_extra_window_radio_jump_takeoff;
+	[Widget] Gtk.Label label_extra_window_radio_jump_more;
+
+	//radio notebook_execute	
+	[Widget] Gtk.RadioButton extra_window_radio_jump_free;
+	[Widget] Gtk.RadioButton extra_window_radio_jump_sj;
+	[Widget] Gtk.RadioButton extra_window_radio_jump_sjl;
+	[Widget] Gtk.RadioButton extra_window_radio_jump_cmj;
+	[Widget] Gtk.RadioButton extra_window_radio_jump_cmjl;
+	[Widget] Gtk.RadioButton extra_window_radio_jump_abk;
+	[Widget] Gtk.RadioButton extra_window_radio_jump_dj;
+	[Widget] Gtk.RadioButton extra_window_radio_jump_rocket;
+	[Widget] Gtk.RadioButton extra_window_radio_jump_takeoff;
+	[Widget] Gtk.RadioButton extra_window_radio_jump_more;
+	
+	[Widget] Gtk.Label label_extra_window_radio_jump_rj_j;
+	[Widget] Gtk.Label label_extra_window_radio_jump_rj_t;
+	[Widget] Gtk.Label label_extra_window_radio_jump_rj_unlimited;
+	[Widget] Gtk.Label label_extra_window_radio_jump_rj_hexagon;
+	[Widget] Gtk.Label label_extra_window_radio_jump_rj_more;
+
+	[Widget] Gtk.RadioButton extra_window_radio_jump_rj_j;
+	[Widget] Gtk.RadioButton extra_window_radio_jump_rj_t;
+	[Widget] Gtk.RadioButton extra_window_radio_jump_rj_unlimited;
+	[Widget] Gtk.RadioButton extra_window_radio_jump_rj_hexagon;
+	[Widget] Gtk.RadioButton extra_window_radio_jump_rj_more;
+
+	//selected test labels	
+	[Widget] Gtk.Label extra_window_jumps_label_selected;
+	[Widget] Gtk.Label extra_window_jumps_rj_label_selected;
 	
 	//for RunAnalysis
 	//but will be used and recorded with "fall"
-	static double distance;
+	//static double distance;
 
-	static string option = "Kg";
-	static double limited = 10;
-	static bool jumpsLimited;
-	static double weight = 20;
-	static bool arms = false;
-	static double fall = 20;
+	//jumps
+	string extra_window_jumps_option = "Kg";
+	double extra_window_jumps_weight = 20;
+	double extra_window_jumps_fall = 20;
+	bool extra_window_jumps_arms = false;
 	
-	static JumpExtraWindow JumpExtraWindowBox;
-	Gtk.Window parent;
+	//jumps_rj
+	double extra_window_jumps_rj_limited = 10;
+	bool extra_window_jumps_rj_jumpsLimited;
+	string extra_window_jumps_rj_option = "Kg";
+	double extra_window_jumps_rj_weight = 20;
+	double extra_window_jumps_rj_fall = 20;
+	
+	private JumpType previousJumpType; //used on More to turnback if cancel or delete event is pressed
+	private JumpType previousJumpRjType; //used on More to turnback if cancel or delete event is pressed
+	
+	private void on_extra_window_jumps_test_changed(object o, EventArgs args)
+	{
+		if(extra_window_radio_jump_free.Active) currentJumpType = new JumpType("Free");
+		else if(extra_window_radio_jump_sj.Active) currentJumpType = new JumpType("SJ");
+		else if(extra_window_radio_jump_sjl.Active) currentJumpType = new JumpType("SJl");
+		else if(extra_window_radio_jump_cmj.Active) currentJumpType = new JumpType("CMJ");
+		else if(extra_window_radio_jump_cmjl.Active) currentJumpType = new JumpType("CMJl");
+		else if(extra_window_radio_jump_abk.Active) currentJumpType = new JumpType("ABK");
+		else if(extra_window_radio_jump_dj.Active) currentJumpType = new JumpType("DJ");
+		else if(extra_window_radio_jump_rocket.Active) currentJumpType = new JumpType("Rocket");
+		else if(extra_window_radio_jump_takeoff.Active) currentJumpType = new JumpType(Constants.TakeOffName);
 
-	JumpExtraWindow (Gtk.Window parent) {
-		Glade.XML gladeXML;
-		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "jump_extra", null);
-		gladeXML.Autoconnect(this);
-		this.parent = parent;
-		
-		//put an icon to window
-		UtilGtk.IconWindow(jump_extra);
+		extra_window_jumps_initialize(currentJumpType);
 	}
 	
-	static public JumpExtraWindow Show (Gtk.Window parent, JumpType myJumpType) 
+	private void on_extra_window_jumps_more(object o, EventArgs args)
 	{
-		if (JumpExtraWindowBox == null) {
-			JumpExtraWindowBox = new JumpExtraWindow (parent);
+		previousJumpType = currentJumpType;
+
+		if(extra_window_radio_jump_more.Active) {
+			jumpsMoreWin = JumpsMoreWindow.Show(app1, true);
+			jumpsMoreWin.Button_accept.Clicked += new EventHandler(on_more_jumps_accepted);
+			jumpsMoreWin.Button_cancel.Clicked += new EventHandler(on_more_jumps_cancelled);
+			jumpsMoreWin.Button_selected.Clicked += new EventHandler(on_more_jumps_draw_image_test);
 		}
+	}
 	
-	/*	
-		if(myJumpType.Name == Constants.RunAnalysisName) {
-			hideRepetitiveData();	
-			hideWeightData();	
-			distance = 100; //100cm
-			
-			JumpExtraWindowBox.spinbutton_fall.Value = distance;
-			JumpExtraWindowBox.label_fall.Text = Catalog.GetString("Distance between photocells");
+	private void on_extra_window_jumps_rj_test_changed(object o, EventArgs args)
+	{
+		if(extra_window_radio_jump_rj_j.Active) currentJumpRjType = new JumpType("RJ(j)");
+		else if(extra_window_radio_jump_rj_t.Active) currentJumpRjType = new JumpType("RJ(t)");
+		else if(extra_window_radio_jump_rj_unlimited.Active) currentJumpRjType = new JumpType("RJ(unlimited)");
+		else if(extra_window_radio_jump_rj_hexagon.Active) currentJumpRjType = new JumpType("RJ(hexagon)");
 
-			JumpExtraWindowBox.spinbutton_fall.Sensitive = true;
-			JumpExtraWindowBox.label_fall.Sensitive = true;
-			JumpExtraWindowBox.label_cm.Sensitive = true;
-		
-			JumpExtraWindowBox.jump_extra.Show ();
+		extra_window_jumps_rj_initialize(currentJumpRjType);
+	}
 
-			return JumpExtraWindowBox;
+	private void on_extra_window_jumps_rj_more(object o, EventArgs args) 
+	{
+		previousJumpRjType = currentJumpRjType;
+
+		if(extra_window_radio_jump_rj_more.Active) {
+			jumpsRjMoreWin = JumpsRjMoreWindow.Show(app1, true);
+			jumpsRjMoreWin.Button_accept.Clicked += new EventHandler(on_more_jumps_rj_accepted);
+			jumpsRjMoreWin.Button_cancel.Clicked += new EventHandler(on_more_jumps_rj_cancelled);
+			jumpsRjMoreWin.Button_selected.Clicked += new EventHandler(on_more_jumps_rj_draw_image_test);
+		}
+	}
+
+
+	private void extra_window_jumps_initialize(JumpType myJumpType) 
+	{
+		extra_window_jumps_label_selected.Text = "<b>" + Catalog.GetString(myJumpType.Name) + "</b>";
+		extra_window_jumps_label_selected.UseMarkup = true; 
+		currentEventType = myJumpType;
+		changeTestImage(EventType.Types.JUMP.ToString(), myJumpType.Name, myJumpType.ImageFileName);
+		bool hasOptions = false;
+	
+		if(myJumpType.HasWeight) {
+			hasOptions = true;
+			extra_window_showWeightData(myJumpType, true);	
+		} else 
+			extra_window_showWeightData(myJumpType, false);	
+
+		if(myJumpType.StartIn || myJumpType.Name == Constants.TakeOffName || 
+				myJumpType.Name == Constants.TakeOffWeightName) 
+			extra_window_showFallData(myJumpType, false);	
+		else {
+			hasOptions = true;
+			extra_window_showFallData(myJumpType, true);
 		}
-		*/
 		
-		if(myJumpType.IsRepetitive) {
+		if(myJumpType.Name == "DJa" || myJumpType.Name == "DJna") { 
+			//on DJa and DJna (coming from More jumps) need to show technique data but not change
+			if(myJumpType.Name == "DJa")
+				extra_window_jumps_check_dj_arms.Active = true;
+			else //myJumpType.Name == "DJna"
+				extra_window_jumps_check_dj_arms.Active = false;
+
+			hasOptions = true;
+			extra_window_showTechniqueArmsData(true, false); //visible, sensitive
+		} else if(myJumpType.Name == "DJ") { 
+			//user has pressed DJ button
+			hasOptions = true;
+			extra_window_jumps_check_dj_arms.Active = extra_window_jumps_arms;
+
+			on_extra_window_jumps_check_dj_arms_clicked(new object(), new EventArgs());
+			extra_window_showTechniqueArmsData(true, true); //visible, sensitive
+		} else 
+			extra_window_showTechniqueArmsData(false, false); //visible, sensitive
+		
+		extra_window_jumps_spinbutton_weight.Value = extra_window_jumps_weight;
+		extra_window_jumps_spinbutton_fall.Value = extra_window_jumps_fall;
+		if (extra_window_jumps_option == "Kg") {
+			extra_window_jumps_radiobutton_kg.Active = true;
+		} else {
+			extra_window_jumps_radiobutton_weight.Active = true;
+		}
+
+		extra_window_jumps_showNoOptions(myJumpType, hasOptions);
+	}
+	
+	private void extra_window_jumps_rj_initialize(JumpType myJumpType) 
+	{
+		extra_window_jumps_rj_label_selected.Text = "<b>" + Catalog.GetString(myJumpType.Name) + "</b>";
+		extra_window_jumps_rj_label_selected.UseMarkup = true; 
+		currentEventType = myJumpType;
+		changeTestImage(EventType.Types.JUMP.ToString(), myJumpType.Name, myJumpType.ImageFileName);
+		bool hasOptions = false;
+	
+		if(myJumpType.FixedValue >= 0) {
+			hasOptions = true;
 			string jumpsName = Catalog.GetString("jumps");
 			string secondsName = Catalog.GetString("seconds");
 			if(myJumpType.JumpsLimited) {
-				jumpsLimited = true;
-				JumpExtraWindowBox.label_limit_units.Text = jumpsName;
+				extra_window_jumps_rj_jumpsLimited = true;
+				extra_window_jumps_rj_label_limit_units.Text = jumpsName;
 			} else {
-				jumpsLimited = false;
-				JumpExtraWindowBox.label_limit_units.Text = secondsName;
+				extra_window_jumps_rj_jumpsLimited = false;
+				extra_window_jumps_rj_label_limit_units.Text = secondsName;
 			}
 			if(myJumpType.FixedValue > 0) {
-				JumpExtraWindowBox.spinbutton_limit.Sensitive = false;
-				JumpExtraWindowBox.spinbutton_limit.Value = myJumpType.FixedValue;
-			} else
-				JumpExtraWindowBox.spinbutton_limit.Value = limited;
+				extra_window_jumps_rj_spinbutton_limit.Sensitive = false;
+				extra_window_jumps_rj_spinbutton_limit.Value = myJumpType.FixedValue;
+			} else {
+				extra_window_jumps_rj_spinbutton_limit.Sensitive = true;
+				extra_window_jumps_rj_spinbutton_limit.Value = extra_window_jumps_rj_limited;
+			}
+			extra_window_showLimitData (true);
+		} else  //unlimited
+			extra_window_showLimitData (false);
+
+		if(myJumpType.HasWeight) {
+			hasOptions = true;
+			extra_window_showWeightData(myJumpType, true);	
+		} else 
+			extra_window_showWeightData(myJumpType, false);	
+
+		if(myJumpType.StartIn || myJumpType.Name == Constants.TakeOffName || 
+				myJumpType.Name == Constants.TakeOffWeightName)
+			extra_window_showFallData(myJumpType, false);	
+		else {
+			extra_window_showFallData(myJumpType, true);	
+			hasOptions = true;
+		}
+		
+		extra_window_jumps_rj_spinbutton_weight.Value = extra_window_jumps_rj_weight;
+		extra_window_jumps_rj_spinbutton_fall.Value = extra_window_jumps_rj_fall;
+		if (extra_window_jumps_rj_option == "Kg") {
+			extra_window_jumps_rj_radiobutton_kg.Active = true;
 		} else {
-			hideRepetitiveData();	
+			extra_window_jumps_rj_radiobutton_weight.Active = true;
 		}
-		if(! myJumpType.HasWeight) {
-			hideWeightData();	
+
+		extra_window_jumps_showNoOptions(myJumpType, hasOptions);
+	}
+
+	private void on_extra_window_jumps_check_dj_arms_clicked(object o, EventArgs args)
+	{
+		JumpType j = new JumpType();
+		if(extra_window_jumps_check_dj_arms.Active) 
+			j = new JumpType("DJa");
+		else
+			j = new JumpType("DJna");
+
+		changeTestImage(EventType.Types.JUMP.ToString(), j.Name, j.ImageFileName);
+	}
+
+
+	private void on_more_jumps_draw_image_test (object o, EventArgs args) {
+		currentEventType = new JumpType(jumpsMoreWin.SelectedEventName);
+		changeTestImage(currentEventType.Type.ToString(), currentEventType.Name, currentEventType.ImageFileName);
+	}
+	
+	private void on_more_jumps_rj_draw_image_test (object o, EventArgs args) {
+		currentEventType = new JumpType(jumpsRjMoreWin.SelectedEventName);
+		changeTestImage(currentEventType.Type.ToString(), currentEventType.Name, currentEventType.ImageFileName);
+	}
+	
+	//used from the dialogue "jumps more"
+	private void on_more_jumps_accepted (object o, EventArgs args) 
+	{
+		jumpsMoreWin.Button_accept.Clicked -= new EventHandler(on_more_jumps_accepted);
+		
+		currentJumpType = new JumpType(
+				//jumpsMoreWin.SelectedJumpType,
+				jumpsMoreWin.SelectedEventName, //type of jump
+								//SelectedEventType would be: jump, or run, ...
+				jumpsMoreWin.SelectedStartIn,
+				jumpsMoreWin.SelectedExtraWeight,
+				false,		//isRepetitive
+				false,		//jumpsLimited (false, because is not repetitive)
+				0,		//limitValue
+				false,		//unlimited
+				jumpsMoreWin.SelectedDescription,
+				SqliteEvent.GraphLinkSelectFileName("jump", jumpsMoreWin.SelectedEventName)
+				);
+	
+		extra_window_jumps_toggle_desired_button_on_toolbar(currentJumpType);
+		
+		//destroy the win for not having updating problems if a new jump type is created
+		//jumpsMoreWin = null; //don't work
+		jumpsMoreWin.Destroy(); //works ;)
+	}
+	
+	//used from the dialogue "jumps rj more"
+	private void on_more_jumps_rj_accepted (object o, EventArgs args) 
+	{
+		jumpsRjMoreWin.Button_accept.Clicked -= new EventHandler(on_more_jumps_rj_accepted);
+
+		currentJumpRjType = new JumpType(
+				//jumpsRjMoreWin.SelectedJumpType,
+				jumpsRjMoreWin.SelectedEventName,
+				jumpsRjMoreWin.SelectedStartIn,
+				jumpsRjMoreWin.SelectedExtraWeight,
+				true,		//isRepetitive
+				jumpsRjMoreWin.SelectedLimited,
+				jumpsRjMoreWin.SelectedLimitedValue,
+				jumpsRjMoreWin.SelectedUnlimited,
+				jumpsRjMoreWin.SelectedDescription,
+				SqliteEvent.GraphLinkSelectFileName("jumpRj", jumpsRjMoreWin.SelectedEventName)
+				);
+
+		
+		extra_window_jumps_rj_toggle_desired_button_on_toolbar(currentJumpRjType);
+	
+		//destroy the win for not having updating problems if a new jump type is created
+		jumpsRjMoreWin.Destroy();
+	}
+
+	//if it's cancelled (or deleted event) select desired toolbar button
+	private void on_more_jumps_cancelled (object o, EventArgs args) 
+	{
+		currentJumpType = previousJumpType;
+		extra_window_jumps_toggle_desired_button_on_toolbar(currentJumpType);
+	}
+	
+	private void on_more_jumps_rj_cancelled (object o, EventArgs args) 
+	{
+		currentJumpRjType = previousJumpRjType;
+		extra_window_jumps_rj_toggle_desired_button_on_toolbar(currentJumpRjType);
+	}
+	
+	private void extra_window_jumps_toggle_desired_button_on_toolbar(JumpType type) {
+		if(type.Name == "Free") extra_window_radio_jump_free.Active = true;
+		else if(type.Name == "SJ") extra_window_radio_jump_sj.Active = true;
+		else if(type.Name == "SJl") extra_window_radio_jump_sjl.Active = true;
+		else if(type.Name == "CMJ") extra_window_radio_jump_cmj.Active = true;
+		else if(type.Name == "CMJl") extra_window_radio_jump_cmjl.Active = true;
+		else if(type.Name == "ABK") extra_window_radio_jump_abk.Active = true;
+//		else if(type.Name == "DJ") extra_window_radio_jump_dj.Active = true;
+		else if(type.Name == "Rocket") extra_window_radio_jump_rocket.Active = true;
+		else if(type.Name == Constants.TakeOffName) extra_window_radio_jump_takeoff.Active = true;
+		else {
+			//don't do this:
+			//extra_window_radio_jump_more.Active = true;
+			//because it will be a loop
+			//only do:
+			extra_window_jumps_initialize(type);
 		}
-		if(myJumpType.StartIn || myJumpType.Name == Constants.TakeOffName || myJumpType.Name == Constants.TakeOffWeightName)
-			       hideFallData();	
-		
-		//show technique (arms) only in DJ
-		if(myJumpType.StartIn || myJumpType.IsRepetitive)
-			hideTechniqueArmsData();
-		
-		JumpExtraWindowBox.check_dj_arms.Active = arms;
-		JumpExtraWindowBox.spinbutton_weight.Value = weight;
-		JumpExtraWindowBox.spinbutton_fall.Value = fall;
-		if (option == "Kg") {
-			JumpExtraWindowBox.radiobutton_kg.Active = true;
+	}
+
+	private void extra_window_jumps_rj_toggle_desired_button_on_toolbar(JumpType type) {
+		if(type.Name == "RJ(j)") extra_window_radio_jump_rj_j.Active = true;
+		else if(type.Name == "RJ(t)") extra_window_radio_jump_rj_t.Active = true;
+		else if(type.Name == "RJ(unlimited)") extra_window_radio_jump_rj_unlimited.Active = true;
+		else if(type.Name == "RJ(hexagon)") extra_window_radio_jump_rj_hexagon.Active = true;
+		else {
+			//don't do this:
+			//extra_window_radio_jump_more.Active = true;
+			//because it will be a loop
+			//only do:
+			extra_window_jumps_rj_initialize(type);
+		}
+	}
+
+	private void extra_window_showWeightData (JumpType myJumpType, bool show) {
+		if(myJumpType.IsRepetitive) {
+			extra_window_jumps_rj_label_weight.Visible = show;
+			extra_window_jumps_rj_spinbutton_weight.Visible = show;
+			extra_window_jumps_rj_radiobutton_kg.Visible = show;
+			extra_window_jumps_rj_radiobutton_weight.Visible = show;
 		} else {
-			JumpExtraWindowBox.radiobutton_weight.Active = true;
-		}
-		
-		JumpExtraWindowBox.jump_extra.Show ();
-
-		return JumpExtraWindowBox;
-	}
-	
-	static void hideRepetitiveData () {
-		JumpExtraWindowBox.label_limit.Hide();
-		JumpExtraWindowBox.spinbutton_limit.Hide();
-		JumpExtraWindowBox.label_limit_units.Hide();
-	}
-	
-	static void hideWeightData () {
-		JumpExtraWindowBox.label_weight.Hide();
-		JumpExtraWindowBox.spinbutton_weight.Hide();
-		JumpExtraWindowBox.radiobutton_kg.Hide();
-		JumpExtraWindowBox.radiobutton_weight.Hide();
-	}
-	
-	static void hideTechniqueArmsData () {
-		JumpExtraWindowBox.label_dj_arms.Hide();
-		JumpExtraWindowBox.check_dj_arms.Hide();
-	}
-	
-	static void hideFallData () {
-		JumpExtraWindowBox.label_fall.Hide();
-		JumpExtraWindowBox.spinbutton_fall.Hide();
-		JumpExtraWindowBox.label_cm.Hide();
-	}
-	
-	void on_button_cancel_clicked (object o, EventArgs args)
-	{
-		JumpExtraWindowBox.jump_extra.Hide();
-		JumpExtraWindowBox = null;
-	}
-	
-	void on_jump_extra_delete_event (object o, DeleteEventArgs args)
-	{
-		JumpExtraWindowBox.jump_extra.Hide();
-		JumpExtraWindowBox = null;
-	}
-	
-	void on_button_accept_clicked (object o, EventArgs args)
-	{
-		limited = (double) spinbutton_limit.Value;
-		weight = (double) spinbutton_weight.Value;
-		fall = (double) spinbutton_fall.Value;
-		distance = (double) spinbutton_fall.Value;
-		arms = check_dj_arms.Active;
-		
-		JumpExtraWindowBox.jump_extra.Hide();
-		JumpExtraWindowBox = null;
-	}
-
-	void on_radiobutton_kg_toggled (object o, EventArgs args)
-	{
-		option = "Kg";
-		Log.WriteLine(string.Format("option: {0}", option));
-	}
-	
-	void on_radiobutton_weight_toggled (object o, EventArgs args)
-	{
-		option = "%";
-		Log.WriteLine(string.Format("option: {0}", option));
-	}
-
-	public Button Button_accept 
-	{
-		set { button_accept = value;	}
-		get { return button_accept;	}
-	}
-
-	public string Option {
-		get { return option; }
-	}
-
-	public bool JumpsLimited {
-		get { return jumpsLimited; }
-	}
-	
-	public double Limited {
-		get { return limited; }
-	}
-	
-	public string LimitString
-	{
-		get { 
-			if(jumpsLimited) 
-				return limited.ToString() + "J";
-			else 
-				return Limited.ToString() + "T";
+			extra_window_jumps_label_weight.Visible = show;
+			extra_window_jumps_spinbutton_weight.Visible = show;
+			extra_window_jumps_radiobutton_kg.Visible = show;
+			extra_window_jumps_radiobutton_weight.Visible = show;
 		}
 	}
 	
-	public double Weight {
-		get { return weight; }
+	private void extra_window_showTechniqueArmsData (bool show, bool sensitive) {
+		extra_window_jumps_label_dj_arms.Visible = show;
+		extra_window_jumps_check_dj_arms.Visible = show;
+		
+		extra_window_jumps_label_dj_arms.Sensitive = sensitive;
+		extra_window_jumps_check_dj_arms.Sensitive = sensitive;
 	}
 	
-	public bool Arms {
-		get { return arms; }
+	private void extra_window_showFallData (JumpType myJumpType, bool show) {
+		if(myJumpType.IsRepetitive) {
+			extra_window_jumps_rj_label_fall.Visible = show;
+			extra_window_jumps_rj_spinbutton_fall.Visible = show;
+			extra_window_jumps_rj_label_cm.Visible = show;
+		} else {
+			extra_window_jumps_label_fall.Visible = show;
+			extra_window_jumps_spinbutton_fall.Visible = show;
+			extra_window_jumps_label_cm.Visible = show;
+		}
+	}
+	
+	private void extra_window_showLimitData (bool show) {
+		extra_window_jumps_rj_label_limit.Visible = show;
+		extra_window_jumps_rj_spinbutton_limit.Visible = show;
+		extra_window_jumps_rj_label_limit_units.Visible = show;
+	}
+	
+			
+	private void extra_window_jumps_showNoOptions(JumpType myJumpType, bool hasOptions) {
+		if(myJumpType.IsRepetitive) 
+			extra_window_label_jumps_rj_no_options.Visible = ! hasOptions;
+		else 
+			extra_window_label_jumps_no_options.Visible = ! hasOptions;
 	}
 
-	public double Fall {
-		get { return fall; }
+
+
+	private void on_extra_window_jumps_radiobutton_kg_toggled (object o, EventArgs args)
+	{
+		extra_window_jumps_option = "Kg";
 	}
+	
+	private void on_extra_window_jumps_radiobutton_weight_toggled (object o, EventArgs args)
+	{
+		extra_window_jumps_option = "%";
+	}
+	
+	private void on_extra_window_jumps_rj_radiobutton_kg_toggled (object o, EventArgs args)
+	{
+		extra_window_jumps_rj_option = "Kg";
+	}
+	
+	private void on_extra_window_jumps_rj_radiobutton_weight_toggled (object o, EventArgs args)
+	{
+		extra_window_jumps_rj_option = "%";
+	}
+	
+	
+	private string limitString()
+	{
+		if(extra_window_jumps_rj_jumpsLimited) 
+			return extra_window_jumps_rj_limited.ToString() + "J";
+		else 
+			return extra_window_jumps_rj_limited.ToString() + "T";
+	}
+
 }
 
 
@@ -1126,6 +1377,10 @@ public class JumpsMoreWindow : EventMoreWindow
 		}
 	}
 	
+	protected override void deleteTestLine() {
+		SqliteJumpType.Delete(Constants.JumpTypeTable, selectedEventName, false);
+	}
+
 	protected override string [] findTestTypesInSessions() {
 		return SqliteJump.SelectJumps(-1, -1, "", selectedEventName); 
 	}
@@ -1138,8 +1393,11 @@ public class JumpsMoreWindow : EventMoreWindow
 	
 	void on_jumps_runs_more_delete_event (object o, DeleteEventArgs args)
 	{
-		JumpsMoreWindowBox.jumps_runs_more.Hide();
-		JumpsMoreWindowBox = null;
+		//raise signal
+		button_cancel.Click();
+
+		//JumpsMoreWindowBox.jumps_runs_more.Hide();
+		//JumpsMoreWindowBox = null;
 	}
 	
 	void on_button_accept_clicked (object o, EventArgs args)
@@ -1311,11 +1569,12 @@ public class JumpsRjMoreWindow : EventMoreWindow
 				selectedLimited = true;
 			}
 			
-			if( (string) model.GetValue (iter, 2) == "?" || (string) model.GetValue (iter, 2) == "-") {
+			if( (string) model.GetValue (iter, 2) == "?")
 				selectedLimitedValue = 0;
-			} else {
+			else if( (string) model.GetValue (iter, 2) == "-") 
+				selectedLimitedValue = -1.0;
+			else 
 				selectedLimitedValue = Convert.ToDouble( (string) model.GetValue (iter, 2) );
-			}
 
 			if( (string) model.GetValue (iter, 3) == Catalog.GetString("Yes") ) {
 				selectedStartIn = true;
@@ -1358,11 +1617,12 @@ public class JumpsRjMoreWindow : EventMoreWindow
 				selectedLimited = true;
 			}
 			
-			if( (string) model.GetValue (iter, 2) == "?" || (string) model.GetValue (iter, 2) == "-") {
+			if( (string) model.GetValue (iter, 2) == "?")
 				selectedLimitedValue = 0;
-			} else {
+			else if( (string) model.GetValue (iter, 2) == "-") 
+				selectedLimitedValue = -1.0;
+			else 
 				selectedLimitedValue = Convert.ToDouble( (string) model.GetValue (iter, 2) );
-			}
 
 			if( (string) model.GetValue (iter, 3) == Catalog.GetString("Yes") ) {
 				selectedStartIn = true;
@@ -1377,6 +1637,10 @@ public class JumpsRjMoreWindow : EventMoreWindow
 		}
 	}
 	
+	protected override void deleteTestLine() {
+		SqliteJumpType.Delete(Constants.JumpRjTypeTable, selectedEventName, false);
+	}
+	
 	protected override string [] findTestTypesInSessions() {
 		return SqliteJumpRj.SelectJumps(-1, -1, "", selectedEventName); 
 	}
@@ -1389,8 +1653,11 @@ public class JumpsRjMoreWindow : EventMoreWindow
 	
 	void on_jumps_runs_more_delete_event (object o, DeleteEventArgs args)
 	{
-		JumpsRjMoreWindowBox.jumps_runs_more.Hide();
-		JumpsRjMoreWindowBox = null;
+		//raise signal
+		button_cancel.Click();
+
+		//JumpsRjMoreWindowBox.jumps_runs_more.Hide();
+		//JumpsRjMoreWindowBox = null;
 	}
 	
 	void on_button_accept_clicked (object o, EventArgs args)
