@@ -59,11 +59,12 @@ public class TreeViewPersons
 	{
 		treeview.HeadersVisible=true;
 		int i=0;
+		bool visible = false;
 		foreach(string myCol in columnsString) {
-			//treeview.AppendColumn (Catalog.GetString(myCol), new CellRendererText(), "text", i++);
-			UtilGtk.CreateCols(treeview, store, Catalog.GetString(myCol), i++);
+			UtilGtk.CreateCols(treeview, store, Catalog.GetString(myCol), i++, visible);
 			if(i == 1)
 				store.SetSortFunc (0, UtilGtk.IdColumnCompare);
+			visible = true;
 		}
 	}
 	
@@ -126,6 +127,17 @@ public class TreeViewPersons
 		return found;
 	}
 
+		
+	public void SelectNextRow(int personID)
+	{
+		SelectRow(FindRow(personID) +1);
+	}
+	
+	public void SelectPreviousRow(int personID)
+	{
+		SelectRow(FindRow(personID) -1);
+	}
+	
 	//add in the row position by alfabetical order
 	public void Add (string jumperID, string jumperName)
 	{
